@@ -1,33 +1,15 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    Copyright (c) 2010 Dominique Dumont.
-#
-#    This file is part of Config-Model.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
 package Config::Model::Annotation;
 {
-  $Config::Model::Annotation::VERSION = '2.040';
+  $Config::Model::Annotation::VERSION = '2.047';
 }
 
 use Mouse ;
@@ -51,100 +33,6 @@ use Carp qw/croak confess cluck/;
 
 #my $logger = get_logger("Annotation") ;
 
-=head1 NAME
-
-Config::Model::Annotation - Read and write configuration annotations
-
-=head1 VERSION
-
-version 2.040
-
-=head1 SYNOPSIS
-
- use Config::Model ;
- use Log::Log4perl qw(:easy) ;
- Log::Log4perl->easy_init($WARN);
-
- # define configuration tree object
- my $model = Config::Model->new ;
- $model ->create_config_class (
-    name => "MyClass",
-    element => [ 
-        [qw/foo bar/] => { 
-            type => 'leaf',
-            value_type => 'string'
-        },
-        baz => { 
-            type => 'hash',
-            index_type => 'string' ,
-            cargo => {
-                type => 'leaf',
-                value_type => 'string',
-            },
-        },
-        
-    ],
- ) ;
-
- my $inst = $model->instance(root_class_name => 'MyClass' );
-
- my $root = $inst->config_root ;
-
- # put some data in config tree the hard way
- $root->fetch_element('foo')->store('yada') ;
- $root->fetch_element('baz')->fetch_with_id('en')->store('hello') ;
-
- # put annotation the hard way
- $root->fetch_element('foo')->annotation('english') ;
- $root->fetch_element('baz')->fetch_with_id('en')->annotation('also english') ;
-
- # put more data the easy way
- my $step = 'baz:fr=bonjour#french baz:hr="dobar dan"#croatian';
- $root->load( step => $step ) ;
-
- # dump resulting tree with annotations
- print $root->dump_tree;
-
- # save annotations
- my $annotate_saver = Config::Model::Annotation
-  -> new (
-          config_class_name => 'MyClass',
-          instance => $inst ,
-	  root_dir => '/tmp/', # for test
-         ) ;
- $annotate_saver->save ;
-
- # now check content of /tmp/config-model/MyClass-note.pl
-
-
-=head1 DESCRIPTION
-
-This module provides an object that read and write annotations (a bit
-like comments) to and from a configuration tree and save them in a file (not 
-configuration file)
-
-Depending on the effective id of the process, the annotation will be
-saved in:
-
-=over 
-
-=item * 
-
-C<< /var/lib/config-model/<model_name>-note.yml >> for root (EUID == 0)
-
-=item *
-
-C<< ~/.config-model/<model_name>-note.yml >> for normal user (EUID > 0)
-
-=back
-
-=head1 CONSTRUCTOR
-
-Quite standard. The constructor is passed a L<Config::Model::Instance>
-object.
-
-
-=cut
 
 has 'instance' => ( is => 'ro', isa => 'Config::Model::Instance', required => 1 );
 has 'config_class_name' => ( is => 'ro', isa => 'Str', required => 1 ) ;
@@ -181,13 +69,6 @@ sub _set_dir {
 #}
 #
 
-=head1 METHODS
-
-=head2 save()
-
-Save annotations in a file (See L<DESCRIPTION>)
-
-=cut
 
 sub save {
     my $self = shift ;
@@ -273,11 +154,6 @@ sub store_note_in_data {
     $data_ref->{$key} = $note ;
 }
 
-=head2 load()
-
-Loads annotations from a file (See L<DESCRIPTION>)
-
-=cut
 
 sub load {
     my $self = shift ;
@@ -299,16 +175,137 @@ __PACKAGE__ -> meta->make_immutable;
 
 1;
 
+# ABSTRACT: Read and write configuration annotations
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Config::Model::Annotation - Read and write configuration annotations
+
+=head1 VERSION
+
+version 2.047
+
+=head1 SYNOPSIS
+
+ use Config::Model ;
+ use Log::Log4perl qw(:easy) ;
+ Log::Log4perl->easy_init($WARN);
+
+ # define configuration tree object
+ my $model = Config::Model->new ;
+ $model ->create_config_class (
+    name => "MyClass",
+    element => [
+        [qw/foo bar/] => {
+            type => 'leaf',
+            value_type => 'string'
+        },
+        baz => {
+            type => 'hash',
+            index_type => 'string' ,
+            cargo => {
+                type => 'leaf',
+                value_type => 'string',
+            },
+        },
+
+    ],
+ ) ;
+
+ my $inst = $model->instance(root_class_name => 'MyClass' );
+
+ my $root = $inst->config_root ;
+
+ # put some data in config tree the hard way
+ $root->fetch_element('foo')->store('yada') ;
+ $root->fetch_element('baz')->fetch_with_id('en')->store('hello') ;
+
+ # put annotation the hard way
+ $root->fetch_element('foo')->annotation('english') ;
+ $root->fetch_element('baz')->fetch_with_id('en')->annotation('also english') ;
+
+ # put more data the easy way
+ my $step = 'baz:fr=bonjour#french baz:hr="dobar dan"#croatian';
+ $root->load( step => $step ) ;
+
+ # dump resulting tree with annotations
+ print $root->dump_tree;
+
+ # save annotations
+ my $annotate_saver = Config::Model::Annotation
+  -> new (
+          config_class_name => 'MyClass',
+          instance => $inst ,
+	  root_dir => '/tmp/', # for test
+         ) ;
+ $annotate_saver->save ;
+
+ # now check content of /tmp/config-model/MyClass-note.pl
+
+=head1 DESCRIPTION
+
+This module provides an object that read and write annotations (a bit
+like comments) to and from a configuration tree and save them in a file (not
+configuration file)
+
+Depending on the effective id of the process, the annotation will be
+saved in:
+
+=over
+
+=item *
+
+C<< /var/lib/config-model/<model_name>-note.yml >> for root (EUID == 0)
+
+=item *
+
+C<< ~/.config-model/<model_name>-note.yml >> for normal user (EUID > 0)
+
+=back
+
+=head1 CONSTRUCTOR
+
+Quite standard. The constructor is passed a L<Config::Model::Instance>
+object.
+
+=head1 METHODS
+
+=head2 save()
+
+Save annotations in a file (See L<DESCRIPTION>)
+
+=head2 load()
+
+Loads annotations from a file (See L<DESCRIPTION>)
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
 
 =head1 SEE ALSO
 
-L<Config::Model>, 
-L<Config::Model::Node>, 
+L<Config::Model>,
+L<Config::Model::Node>,
 L<Config::Model::Loader>,
 L<Config::Model::Searcher>,
 L<Config::Model::Value>,
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
