@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,10 @@
 #
 package Config::Model::AnyId ;
 {
-  $Config::Model::AnyId::VERSION = '2.021';
+  $Config::Model::AnyId::VERSION = '2.047';
 }
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Config::Model::Exception ;
@@ -20,7 +20,7 @@ use Config::Model::Warper ;
 use Carp qw/cluck croak carp/;
 use Log::Log4perl qw(get_logger :levels);
 use Storable qw/dclone/;
-use Any::Moose '::Util::TypeConstraints';
+use Mouse::Util::TypeConstraints;
 
 extends qw/Config::Model::AnyThing/;
 
@@ -615,7 +615,7 @@ sub check_duplicates {
     return unless @issues ;
     
     if ($apply_fix) {
-        $logger->debug("Fixing duplicates @issues");
+        $logger->debug("Fixing duplicates @issues, removing @to_delete");
         map { $self->remove($_) } reverse @to_delete ;
     }
     elsif ($dup eq 'forbid') {
@@ -680,6 +680,16 @@ sub get {
     my $get_obj = delete $args{get_obj} || 0 ;
     $path =~ s!^/!! ;
     my ($item,$new_path) = split m!/!,$path,2 ;
+    
+    my $dcm = $args{dir_char_mockup} ;
+    # $item =~ s($dcm)(/)g if $dcm ;
+    if ($dcm) {
+        while (1) {
+            my $i = index($item,$dcm) ;
+            last if $i == -1 ;
+            substr $item, $i, length ($dcm), '/' ;
+        }
+    }
 
     return unless ($self->exists($item) or $autoadd) ;
 
@@ -960,19 +970,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Base class for hash or list element
+
 __END__
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::AnyId - Base class for hash or list element
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -1147,13 +1159,12 @@ To perform special set-up on children nodes you can also use
 
    default_with_init =>  { 'foo' => 'X=Av Y=Bv' ,
                            'bar' => 'Y=Av Z=Cv' }
-                           
+
 When the hash contains leaves, you can also use:
 
    default_with_init => { 'def_1' => 'def_1 stuff' ,
                           'def_2' => 'def_2 stuff' }
 
-
 =item migrate_keys_from
 
 Specifies that the keys of the hash are copied from another hash in
@@ -1235,7 +1246,7 @@ The Warp functionality enables an L<HashId|Config::Model::HashId> or
 L<ListId|Config::Model::ListId> object to change its default settings
 (e.g. C<min_index>, C<max_index> or C<max_nb> parameters) dynamically according to
 the value of another C<Value> object. (See
-L<Config::Model::WarpedThing> for explanation on warp mechanism)
+L<Config::Model::Warper> for explanation on warp mechanism)
 
 For instance, with this model:
 
@@ -1272,7 +1283,7 @@ Setting C<macro> to C<B> will mean that C<warped_hash> will accept two
 instances of C<Dummy>.
 
 Like other warped class, a HashId or ListId can have multiple warp
-masters (See L<Config::Model::WarpedThing/"Warp follow argument">:
+masters (See L<Config::Model::Warper/"Warp follow argument">:
 
   warp => { follow => { m1 => '- macro1', 
                         m2 => '- macro2' 
@@ -1376,9 +1387,47 @@ Returns the number of fixes that can be applied to the current value.
 Fetch the collected element held by the hash or list. Index check is 'yes' by default.
 Can be called with one parameter which will be used as index.
 
-=head2 C<get( path => ..., mode => ... ,  check => ... , get_obj => 1|0, autoadd => 1|0)>
+=head2 get(...)
 
-Get a value from a directory like path.
+Get a value from a directory like path. Parameters are:
+
+=over
+
+=item path
+
+Poor man's version of XPath style path. This string is in the form:
+
+ /foo/bar/4
+
+Each word between the '/' is either an element name or a hash key or a list index. 
+
+=item mode
+
+Either C<default>, C<custom>, C<user>,... 
+See C<mode> parameter in <Config::Model::Value/"fetch( ... )">
+
+=item check
+
+Either C<skip>, C<no>
+
+=item get_obj
+
+If the path leads to a leaf, this parameter tell whether to return 
+the stored value or the value object. 
+
+=item autoadd
+
+Whether to create missing keys
+
+=item dir_char_mockup
+
+When the hash key used contains '/', (for instance a directory value),
+the key cannot be used as is with this method. Because '/' is already
+used to separate configuration items (this is also important with
+L<Config::Model::FuseUI>). This parameter specifies how the forbidden
+'/' char is shown in the path. Default is C<< <slash> >>
+
+=back
 
 =head2 set( path, value )
 
@@ -1479,4 +1528,16 @@ L<Config::Model::ListId>,
 L<Config::Model::CheckList>,
 L<Config::Model::Value>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
