@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,14 +9,14 @@
 #
 package Config::Model::AnyThing;
 {
-  $Config::Model::AnyThing::VERSION = '2.029';
+  $Config::Model::AnyThing::VERSION = '2.047';
 }
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 # FIXME: must cleanup warp mechanism to implement this
-# use Any::Moose 'X::StrictConstructor' ;
+# use MouseX::StrictConstructor;
 
 use Pod::POM ;
 use Carp;
@@ -70,7 +70,8 @@ sub notify_change {
 
     return if $self->instance->initial_load  and not $args{really};
 
-    $change_logger->debug("called for ",$self->name, " from ", join(' ',caller) ) 
+    $change_logger->debug("called for ",$self->name, " from ", join(' ',caller),
+        " with ", join( ' ',%args))
         if $change_logger->is_debug ;
 
     # needs_save may be overridden by caller
@@ -79,7 +80,7 @@ sub notify_change {
     $args{name} //= $self->element_name if $self->element_name ;
     $args{index} //= $self->index_value if $self->index_value ;
     
-    # beter use %args instead of @_ to forward arguments. %args eliminates duplicated keys
+    # better use %args instead of @_ to forward arguments. %args eliminates duplicated keys
     $self->container->notify_change(%args);
 }
 
@@ -563,18 +564,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Base class for configuration tree item
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::AnyThing - Base class for configuration tree item
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -648,7 +652,6 @@ be in the form:
  Annotation text
  
  =back
- 
 
 =head1 Information management
 
@@ -783,4 +786,16 @@ L<Config::Model::Node>,
 L<Config::Model::Loader>, 
 L<Config::Model::Dumper>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
