@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,14 +9,14 @@
 #
 package Config::Model::Backend::Any ;
 {
-  $Config::Model::Backend::Any::VERSION = '2.029';
+  $Config::Model::Backend::Any::VERSION = '2.047';
 }
 
 use Carp;
 use strict;
 use warnings ;
 use Config::Model::Exception ;
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use File::Path;
@@ -31,7 +31,7 @@ has 'node'       => ( is => 'ro', isa => 'Config::Model::Node',
 
 sub suffix {
     my $self = shift ;
-    $logger->warn("Internal warning: suffix called for backend $self->{name}.This method can be overloaded") ;
+    $logger->info("Internal warning: suffix called for backend $self->{name}.This method can be overloaded") ;
 }
 
 sub read {
@@ -69,7 +69,7 @@ sub read_global_comments {
     while (defined ( $_ = shift @$lines ) ) {
         chomp ;
 
-        my ($data,$comment) = split /\s*$cc\s?/ ;
+        my ($data,$comment) = split /\s*$cc\s?/ , $_, 2 ;
 
         push @global_comments, $comment if defined $comment ;
 
@@ -96,7 +96,7 @@ sub associates_comments_with_data {
         next if /^$cc$cc/ ;		  # remove comments added by Config::Model
         chomp ;
 
-        my ($data,$comment) = split /\s*$cc\s?/ ;
+        my ($data,$comment) = split /\s*$cc\s?/, $_, 2 ;
         push @comments, $comment        if defined $comment ;
 
         next unless defined $data ;
@@ -119,10 +119,10 @@ sub associates_comments_with_data {
 sub write_global_comment {
     my ($self,$ioh,$cc) = @_ ;
 
-    my $res = "$cc$cc This file was written by Config::Model\n"
-            . "$cc$cc You may modify the content of this file. Configuration \n"
-            . "$cc$cc modifications will be preserved. Modifications in\n"
-            . "$cc$cc comments may be mangled.\n\n" ;
+    my $res = "$cc$cc This file was written by cme command.\n"
+        . "$cc$cc You can run 'cme edit <application>' to modify this file.\n"
+        . "$cc$cc Run 'cme list' to get the list of applications available on your system\n"
+        . "$cc$cc You may also modify the content of this file with your favorite editor.\n\n" ;
 
     # write global comment
     my $global_note = $self->node->annotation ;
@@ -154,20 +154,26 @@ __PACKAGE__->meta->make_immutable ;
 
 1;
 
+# ABSTRACT: Virtual class for other backends
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
  package Config::Model::Backend::Foo ;
- use Any::Moose ;
+ use Mouse ;
  use Log::Log4perl qw(get_logger :levels);
 
  extends 'Config::Model::Backend::Any';
@@ -230,15 +236,15 @@ version 2.029
     return 1;
  }
 
- no Any::Moose ;
+ no Mouse ;
  __PACKAGE__->meta->make_immutable ;
 
 =head1 DESCRIPTION
 
-This L<Moose> class is to be inherited by other backend plugin classes
+This L<Mouse> class is to be inherited by other backend plugin classes
 
-See L<Config::Model::AutoRead/"read callback"> and
-L<Config::Model::AutoRead/"write callback"> for more details on the
+See L<Config::Model::BackendMgr/"read callback"> and
+L<Config::Model::BackendMgr/"write callback"> for more details on the
 method that must be provided by any backend classes.
 
 =head1 CONSTRUCTOR
@@ -298,8 +304,20 @@ Dominique Dumont, (ddumont at cpan dot org)
 =head1 SEE ALSO
 
 L<Config::Model>, 
-L<Config::Model::AutoRead>, 
+L<Config::Model::BackendMgr>, 
 L<Config::Model::Node>, 
 L<Config::Model::Backend::Yaml>, 
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
