@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::Backend::Fstab ;
 {
-  $Config::Model::Backend::Fstab::VERSION = '2.040';
+  $Config::Model::Backend::Fstab::VERSION = '2.047';
 }
 use Mouse ;
 use Carp ;
@@ -150,15 +150,21 @@ __PACKAGE__->meta->make_immutable ;
 
 1;
 
+# ABSTRACT: Read and write config from fstab file
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::Fstab - Read and write config from fstab file
 
 =head1 VERSION
 
-version 2.040
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -215,4 +221,16 @@ L<Config::Model>,
 L<Config::Model::BackendMgr>, 
 L<Config::Model::Backend::Any>, 
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
