@@ -1,41 +1,20 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-# This is free software, licensed under:
-# 
-#   The GNU Lesser General Public License, Version 2.1, February 1999
-# 
-#    Copyright (c) 2010-2011 Dominique Dumont, Krzysztof Tyszecki.
-#
-#    This file is part of Config-Model.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
 package Config::Model::Backend::IniFile ;
 {
-  $Config::Model::Backend::IniFile::VERSION = '2.029';
+  $Config::Model::Backend::IniFile::VERSION = '2.047';
 }
 
 use Carp;
-use Any::Moose ;
+use Mouse ;
+use 5.10.0;
 use Config::Model::Exception ;
 use File::Path;
 use Log::Log4perl qw(get_logger :levels);
@@ -63,23 +42,18 @@ sub read {
 
     return 0 unless defined $args{io_handle};    # no file to read
 
-    my $section;
+    my $section = '<top>'; # dumb value used for logging
 
     my $delimiter   = $args{comment_delimiter}   || '#';
     my $hash_class  = $args{store_class_in_hash} || '' ;
     my $section_map = $args{section_map}         || {} ;
-    my $split_reg   = $args{split_list_value}    || '' ;  
+    my $split_reg   = $args{split_list_value} ;
     my $check       = $args{check}               || 'yes';
     my $obj         = $self->node;
 
     my %force_lc ;
     map { $force_lc{$_} = $args{"force_lc_$_"} ? 1 : 0; } qw/section key value/ ;
 
-    # delay validation after read because the read order depends
-    # on the INI file and not on the model
-    my $read_check = 'no'; 
-    
-
     #FIXME: Is it possible to store the comments with their location
     #in the file?  It would be nice if comments that are after values
     #in input file, would be written in the same way in the output
@@ -90,80 +64,99 @@ sub read {
     $self->read_global_comments(\@lines,$delimiter) ;
 
     my @assoc = $self->associates_comments_with_data( \@lines, $delimiter ) ;
+
+    # store INI data in a structure:
+    # {
+    #   name => value         leaf
+    #   name => [  value ]     list
+    #   name => { key =>  value , ... }    hash
+    #   name => { ... }                   node
+    #   name => [ { ... }, ... ]        list of nodes
+    #   name => { key =>   { ... } , ... }        hash of nodes
+    # }
+
+    my $ini_data = {};
+    my %ini_comment ;
+    my $section_ref = $ini_data ;
+    my $section_path = '';
+
     foreach my $item (@assoc) {
         my ($vdata,$comment) = @$item;
         $logger->debug("ini read: reading '$vdata'");
+        my $comment_path ;
 
         # Update section name
-        if ( $vdata =~ /\[(.*)\]/ ) {
+        if ($vdata =~ /\[(.*)\]/ ) {
             $section = $force_lc{section} ? lc($1) : $1;
-            my $steps = $section_map->{$section} ? $section_map->{$section}.' '
-                      : $hash_class              ? "$hash_class:$section" 
-                      :                            $section ;
-            $logger->debug("use step '$steps' for section '$section'");
-            $obj = $self->node->grab(
-                step  => $steps ,
-                check => $read_check,
-                mode => $read_check eq 'yes' ? 'strict' : 'loose' ,
-            );
-            
-            # for write later, need to store the obj if section map was used
-            if (defined $section_map->{$section}) {
-               my $map_loc = $obj->location ;
-               $logger->debug("store section_map loc '$map_loc' section '$section'");
-               $self->{reverse_section_map}{$map_loc} = $section ;
+            my $remap = $section_map->{$section} || '' ;
+            if ( $remap eq '!') {
+                $section_ref = $ini_data ;
+                $comment_path = $section_path = '';
+                $logger->debug("step 1: found node <top> [$section]");
             }
-            
-            if ($logger->is_debug) {
-                my $debug_loc = defined $obj ? 'on node '.$obj->location : '' ;
-                $logger->debug("ini read: new section '$section' $debug_loc");
+            elsif ($remap) {
+                $section_ref = {} ;
+                $logger->debug("step 1: found node $remap [$section]");
+                $section_path = $comment_path = $self->set_or_push($ini_data, $remap, $section_ref);
             }
-            $obj->annotation($comment) if $comment and defined $obj;
-        }
-        elsif (defined $obj) {
-            my ( $name, $val ) = split( /\s*=\s*/, $vdata );
-            $name = lc($name) if $force_lc{key} ;
-            $val  = lc($val)  if $force_lc{value} ;
-            
-            $logger->debug("ini read: data $name for node ".$obj->location);
-
-            my $elt = $obj->fetch_element( name => $name, check => $read_check );
-
-            if ( $elt->get_type eq 'list' and $split_reg) {
-                my @v_list = split(/$split_reg/,$val) ;
-                my @args = (\@v_list, check => $read_check) ;
-                push @args, annotation => $comment if $comment ;
-                $elt->store_set(@args) ;
-            }
-            elsif ( $elt->get_type eq 'list' ) {
-                my @args = (values => $val, check => $read_check) ;
-                push @args, annotation => $comment if $comment ;
-                $elt -> push_x(@args) ;
-            }
-            elsif ( $elt->get_type eq 'leaf' ) {
-                $elt->store( value => $val, check => $read_check );
-                $elt->annotation($comment) if scalar $comment;
+            elsif ($hash_class) {
+                $ini_data->{$hash_class}{$section} = $section_ref = { } ;
+                $comment_path = $section_path =  "$hash_class:$section" ;
+                $logger->debug("step 1: found node $hash_class and path $comment_path [$section]");
             }
             else {
-                Config::Model::Exception::ModelDeclaration->throw(
-                    error => "element $elt must be list or leaf for INI files",
-                    object => $obj
-                );
+                $section_ref = {} ;
+                $logger->debug("step 1: found node $section [$section]");
+                $section_path = $comment_path = $self->set_or_push($ini_data, $section, $section_ref);
+            }
+            # for write later, need to store the obj if section map was used
+            if (defined $section_map->{$section}) {
+               $logger->debug("store section_map loc '$section_path' section '$section'");
+               $self->{reverse_section_map}{$section_path} = $section ;
             }
         }
         else {
-            $logger->warn("ini read: skipping $vdata");
+            my ( $name, $val ) = split( /\s*=\s*/, $vdata );
+            $name = lc($name) if $force_lc{key} ;
+            $val  = lc($val)  if $force_lc{value} ;
+            $comment_path = $section_path.' '.$self->set_or_push($section_ref, $name, $val);
+            $logger->debug("step 1: found node $comment_path name $name in [$section]");
         }
+
+        $ini_comment{$comment_path} = $comment if $comment ;
     }
 
-    # perform check if it was not done before
-    if ($check ne 'no') {
-        $obj->dump_tree(check => $check) ;
-    }
+    my @load_args = ( data => $ini_data, check => $check ) ;
+    push @load_args, split_reg => qr/$split_reg/ if $split_reg ;
+    $obj->load_data(@load_args) ;
+
+    while (my ($k,$v) = each %ini_comment) {
+        my $item = $obj->grab(step => $k, mode => 'loose') or next;
+        $item= $item->fetch_with_id(0) if $item->get_type eq 'list' ;
+        $item->annotation($v) ;
+    } ;
 
     return 1;
 }
 
+sub set_or_push {
+    my ( $self, $ref, $name, $val ) = @_;
+    my $cell = $ref->{$name};
+    my $path ;
+    if ( defined $cell and ref($cell) eq 'ARRAY' ) {
+        push @$cell, $val;
+        $path = $name.':'. $#$cell
+    }
+    elsif ( defined $cell ) {
+        $ref->{$name} = [ $cell, $val ];
+        $path = $name.':1' ;
+    }
+    else {
+        $ref->{$name} = $val ;
+        $path = $name ; # no way to distinguish between leaf and first value of list
+    }
+    return $path;
+}
 
 sub write {
     my $self = shift;
@@ -243,7 +236,7 @@ sub _write {
         }
         elsif ($node->element_type($elt) eq 'leaf') {
             my $v = $obj->fetch ;
-            if ($write_bool_as and length($v) and $obj->value_type eq 'boolean') {
+            if ($write_bool_as and defined($v) and length($v) and $obj->value_type eq 'boolean') {
                 $v = $write_bool_as->[$v] ;
             }
             if (defined $v and length $v) {
@@ -302,21 +295,27 @@ sub _write {
     return $res ;
 }
 
-no Any::Moose ;
+no Mouse ;
 __PACKAGE__->meta->make_immutable ;
 
 
 1;
 
+# ABSTRACT: Read and write config as a INI file
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::IniFile - Read and write config as a INI file
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -406,7 +405,7 @@ comment may apply. Wrong estimations are possible.
 =head2 new ( node => $node_obj, name => 'inifile' ) ;
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
-called by L<Config::Model::AutoRead>.
+called by L<Config::Model::BackendMgr>.
 
 =head1 Parameters
 
@@ -477,14 +476,14 @@ The elements of each class can be different. For instance:
 In this case, class C<A> and class C<B> will not use the same configuration class.
 
 The model will have this structure:
-   
+
  Root class 
  |- leaf element foo
  |- node element A of class_A
  |  \- leaf element bar
  \- node element B of class_B
     \-  leaf element baz
-    
+
 =head2 Arbitrary class name
 
 In this case, the class names can be chosen by the end user. Each class will have the same 
@@ -498,7 +497,7 @@ elements. For instance:
 
 In this case, class C<A> and class C<B> will not use the same configuration class.
 The model will have this structure:
-   
+
  Root class 
  |- leaf foo
  \- hash element my_class_holder
@@ -518,7 +517,7 @@ parameter:
             store_class_in_hash => 'my_class_holder',
         }
     ],
-    
+
 Of course they are exceptions. For instance, in C<Multistrap>, the C<[General]> 
 INI class must be mapped to a specific node object. This can be specified
 with the C<section_map> parameter: 
@@ -547,7 +546,6 @@ C<section_map> can also map an INI class to the root node:
         }
     ],
 
-
 =head1 Methods
 
 =head2 read ( io_handle => ... )
@@ -576,7 +574,19 @@ Krzysztof Tyszecki, (krzysztof.tyszecki at gmail dot com)
 =head1 SEE ALSO
 
 L<Config::Model>, 
-L<Config::Model::AutoRead>, 
+L<Config::Model::BackendMgr>, 
 L<Config::Model::Backend::Any>, 
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
