@@ -1,39 +1,20 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    Copyright (c) 2010-2011 Dominique Dumont.
-#
-#    This file is part of Config-Model.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
 package Config::Model::Backend::ShellVar ;
 {
-  $Config::Model::Backend::ShellVar::VERSION = '2.021';
+  $Config::Model::Backend::ShellVar::VERSION = '2.047';
 }
 
 use Carp;
-use Any::Moose ;
+use Mouse ;
 use Config::Model::Exception ;
-use UNIVERSAL ;
 use File::Path;
 use Log::Log4perl qw(get_logger :levels);
 
@@ -68,6 +49,7 @@ sub read {
     my @assoc = $self->associates_comments_with_data( \@lines, '#' ) ;
     foreach my $item (@assoc) {
         my ($data,$c) = @$item;
+        $data =~ s/\s*=\s*/=/; # make reader quite tolerant
         my $load = qq!$data! ;
         $load .= qq!#"$c"! if $c ;
         $logger->debug("Loading:$load\n");
@@ -115,20 +97,26 @@ sub write {
     return 1;
 }
 
-no Any::Moose ;
+no Mouse ;
 __PACKAGE__->meta->make_immutable ;
 
 1;
 
+# ABSTRACT: Read and write config as a C<SHELLVAR> data structure
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Backend::ShellVar - Read and write config as a C<SHELLVAR> data structure
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -181,13 +169,12 @@ Note that undefined values are skipped for list element. I.e. if a
 list element contains C<('a',undef,'b')>, the data structure will
 contain C<'a','b'>.
 
-
 =head1 CONSTRUCTOR
 
 =head2 new ( node => $node_obj, name => 'shellvar' ) ;
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
-called by L<Config::Model::AutoRead>.
+called by L<Config::Model::BackendMgr>.
 
 =head2 read ( io_handle => ... )
 
@@ -214,7 +201,19 @@ Dominique Dumont, (ddumont at cpan dot org)
 =head1 SEE ALSO
 
 L<Config::Model>, 
-L<Config::Model::AutoRead>, 
+L<Config::Model::BackendMgr>, 
 L<Config::Model::Backend::Any>, 
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
