@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,10 @@
 #
 package Config::Model::BackendMgr ;
 {
-  $Config::Model::BackendMgr::VERSION = '2.021';
+  $Config::Model::BackendMgr::VERSION = '2.047';
 }
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Carp;
@@ -20,6 +20,7 @@ use Carp;
 use Config::Model::Exception ;
 use Data::Dumper ;
 use File::Path ;
+use File::Copy ;
 use File::HomeDir ;
 use IO::File ;
 use Storable qw/dclone/ ;
@@ -28,6 +29,11 @@ use Log::Log4perl qw(get_logger :levels);
 
 my $logger = get_logger('BackendMgr') ;
 
+# used only for tests
+my $__test_home = '';
+sub _set_test_home { $__test_home = shift ;}
+
+
 # one BackendMgr per file
 
 has 'node' => (
@@ -45,30 +51,17 @@ has 'backend' => (
     handles => { set_backend => 'set', get_backend => 'get' }
 );
 
-sub get_cfg_file_path {
-    my $self = shift ; 
+#
+# New subroutine "get_cfg_dir_path" extracted - Thu Jul 11 13:47:22 2013.
+#
+sub get_cfg_dir_path {
+    my $self = shift ;
     my %args = @_;
 
     my $w = $args{write} || 0 ;
-
-    # config file override
-    if (defined $args{config_file}) {
-        my $override = $args{root}.$args{config_file}  ;
-         $logger->trace("auto_". ($w ? 'write' : 'read') 
-                  ." $args{backend} override target file is $override" );
-        return $args{root}.$args{config_file} 
-    }
-
-    Config::Model::Exception::Model -> throw (
-         error=> "auto_". ($w ? 'write' : 'read') 
-                 ." error: empty 'config_dir' parameter (and no config_file override)",
-         object => $self->node
-    ) unless $args{config_dir};
-
-    my $dir = $args{config_dir} ;
+    my $dir = $args{os_config_dir}{$^O} || $args{config_dir} ;
     if ($dir =~ /^~/) { 
-        # also works also on Windows. Not that I care, just trying to be nice
-        my $home = File::HomeDir->my_data; 
+        my $home = $__test_home || File::HomeDir->my_home;
         $dir =~ s/^~/$home/;
     }
     
@@ -81,20 +74,46 @@ sub get_cfg_file_path {
     }
 
     unless (-d $dir) { 
-        $logger->info( "get_cfg_file_path: auto_". ($w ? 'write' : 'read') 
+        $logger->info( "auto_". ($w ? 'write' : 'read')
                       ." $args{backend} no directory $dir" );
-        return;
+        return (0, $dir);
     }
 
+    $logger->debug("dir: ". $dir // '<undef>') ;
+
+    return (1, $dir);
+}
+
+sub get_cfg_file_path {
+    my $self = shift ;
+    my %args = @_;
+
+    my $w = $args{write} || 0 ;
+
+    # config file override
+    if (defined $args{config_file}) {
+        my $override = $args{root}.$args{config_file}  ;
+         $logger->trace("auto_". ($w ? 'write' : 'read')
+                  ." $args{backend} override target file is $override" );
+        return (1, $args{root}.$args{config_file});
+    }
+
+    Config::Model::Exception::Model -> throw (
+         error=> "backend error: empty 'config_dir' parameter (and no config_file override)",
+         object => $self->node
+    ) unless $args{config_dir};
+
+    my ($dir_ok,$dir) = $self->get_cfg_dir_path (%args);
+
     if (defined $args{file}) {
         my $res = $dir.$args{file} ;
-        $logger->trace("get_cfg_file_path: returns $res"); 
-        return $res ;
+        $logger->trace("get_cfg_file_path: returns $res");
+        return ($dir_ok, $res) ;
     }
 
     if (not defined $args{suffix}) {
-        $logger->trace("get_cfg_file_path: returns undef (no suffix, no file argument)"); 
-        return ;
+        $logger->trace("get_cfg_file_path: returns undef (no suffix, no file argument)");
+        return (0);
     }
 
     my $i = $self->node->instance ;
@@ -113,34 +132,34 @@ sub get_cfg_file_path {
 
     $name .= $args{suffix} ;
 
-    $logger->trace("get_cfg_file_path: auto_". ($w ? 'write' : 'read') 
+    $logger->trace("get_cfg_file_path: auto_". ($w ? 'write' : 'read')
                   ." $args{backend} target file is $name" );
 
-    return $name;
+    return (1,$name);
 }
 
 sub open_read_file {
     my $self = shift ;
     my %args = @_ ;
 
-    my $file_path = $self->get_cfg_file_path(%args);
+    my ($file_ok,$file_path) = $self->get_cfg_file_path(%args);
 
     # not very clean
-    return if $args{backend} =~ /_file$/
-        and (not defined $file_path or not -r $file_path) ;
+    return (0, $file_path) if $args{backend} =~ /_file$/
+        and (not $file_ok or not -r $file_path) ;
 
     my $fh = new IO::File;
-    if (defined $file_path and -e $file_path) {
+    if ($file_ok and -e $file_path) {
         $logger->debug("open_read_file: open $file_path for read");
         $fh->open($file_path);
         $fh->binmode(":utf8");
         # store a backup in memory in case there's a problem
         $self->file_backup( [ $fh-> getlines ] ) ;
         $fh->seek(0,0) ; # go back to beginning of file
-        return ($file_path,$fh) ;
+        return (1,$file_path,$fh) ;
     }
     else {
-        return $file_path ;
+        return (0,$file_path) ;
     }
 }
 
@@ -215,7 +234,7 @@ sub read_config_data {
 
     # r_dir is obsolete
     if (defined $r_dir) {
-        warn $self->node->config_class_name," : read_config_dir is obsolete\n";
+        die $self->node->config_class_name," : read_config_dir is obsolete\n";
     }
 
     my $readlist = dclone $readlist_orig ;
@@ -233,108 +252,33 @@ sub read_config_data {
     my $pref_backend = $instance->backend || '' ;
     my $read_done = 0;
     my $auto_create = 0;
+    my @tried;
 
     foreach my $read (@list) {
         warn $self->config_class_name,
-          " deprecated 'syntax' parameter in auto_read\n" if defined $read->{syntax} ;
+          " deprecated 'syntax' parameter in backend\n" if defined $read->{syntax} ;
         my $backend = delete $read->{backend} || delete $read->{syntax} || 'custom';
         if ($backend =~ /^(perl|ini|cds)$/) {
             warn $self->config_class_name,
-              " deprecated auto_read backend $backend. Should be '$ {backend}_file'\n";
+              " deprecated  backend $backend. Should be '$ {backend}_file'\n";
             $backend .= "_file" ;
         }
 
         next if ($pref_backend and $backend ne $pref_backend) ;
 
-        my $read_dir = delete $read->{config_dir} || $r_dir || ''; # $r_dir obsolete
-        $read_dir .= '/' if $read_dir and $read_dir !~ m(/$) ; 
-
         if (defined $read->{allow_empty}) {
-          warn "backend $backend: allow_empty is deprecated. Use auto_create";
-          $auto_create ||= delete $read->{allow_empty} ;
+            warn "backend $backend: allow_empty is deprecated. Use auto_create";
+            $auto_create ||= delete $read->{allow_empty} ;
         }
 
         $auto_create ||= delete $read->{auto_create} if defined $read->{auto_create};
 
-        my @read_args = (%$read, root => $root_dir, config_dir => $read_dir,
-                        backend => $backend, check => $check, 
-                        config_file => $config_file_override);
-        
-        my ($res,$fh,$file_path) ;
-
-        if ($backend eq 'custom') {
-            my $c = my $file = delete $read->{class} ;
-            $file =~ s!::!/!g;
-            my $f = delete $read->{function} || 'read' ;
-            require $file.'.pm' unless $c->can($f);
-            no strict 'refs';
-
-            $logger->info("Read with custom backend $ {c}::$f in dir $read_dir");
-
-            ($file_path,$fh) = $self->open_read_file(@read_args);
-            eval {
-                $res = &{ $c . '::' . $f }(
-                    @read_args,
-                    file_path => $file_path,
-                    io_handle => $fh,
-                    object    => $self->node
-                );
-            };
-        }
-        elsif ($backend eq 'perl_file') {
-            ($file_path,$fh) = $self->open_read_file(@read_args,
-                                                       suffix => '.pl');
-            next unless defined $file_path ;
-            eval {
-                $res = $self->read_perl(@read_args, 
-                                       file_path => $file_path,
-                                       io_handle => $fh);
-            }
-        }
-        elsif ($backend eq 'cds_file') {
-            ($file_path,$fh) = $self->open_read_file(@read_args,
-                                                        suffix => '.cds');
-            next unless defined $file_path ;
-            eval { 
-                $res = $self->read_cds_file(@read_args, 
-                                           file_path => $file_path,
-                                           io_handle => $fh,);
-            } ;
-        }
-        else {
-            # try to load a specific Backend class
-            my $f = delete $read->{function} || 'read' ;
-            my $c = load_backend_class ($backend, $f);
-            next unless defined $c;
-
-            no strict 'refs';
-            my $backend_obj = $c->new(node => $self->node, name => $backend) ;
-            $self->set_backend($backend => $backend_obj) ; 
-            my $suffix ;
-            $suffix = $backend_obj->suffix if $backend_obj->can('suffix');
-            ($file_path,$fh) = $self->open_read_file(@read_args,
-                                                        suffix => $suffix);
-            $logger->info("Read with $backend ".$c."::$f");
-
-            eval {
-                $res = $backend_obj->$f(@read_args, 
-                                       file_path => $file_path,
-                                       io_handle => $fh,
-                                       object => $self->node,
-                                      );
-            } ;
+        if ($read->{default_layer}) {
+            $self->read_config_sub_layer($read, $root_dir, $config_file_override, $check, $backend);
         }
 
-        # catch eval errors done in the if-then-else block before
-        my $e ;
-        if ( $e = Exception::Class->caught('Config::Model::Exception::Syntax') ) {
-            # FIXME: this is naughty. Should file a bug to add info in rethrow
-            $e->{parsed_file} = $file_path unless $e->parsed_file ;
-            $e->rethrow ;
-        }
-        elsif ( $e = Exception::Class->caught() ) {
-            ref $e ? $e->rethrow : die $e;
-        }
+        my ($res, $file) = $self->try_read_backend ($read, $root_dir, $config_file_override, $check, $backend);
+        push @tried, $file;
 
         if ($res) { 
             $read_done = 1 ;
@@ -342,26 +286,145 @@ sub read_config_data {
         }
     }
 
-    if (not $read_done) {
-        my $msg = "could not read config file " ;
-        $msg .= $config_file_override.' ' if defined $config_file_override ;
-        $msg .= "with ";
-        $msg .= $pref_backend ? "'$pref_backend'" : 'any' ;
-        $msg .= " backend";
-
-        Config::Model::Exception::Model -> throw
-            (
-             error => "auto_read error: $msg. May be add "
-                    . "'auto_create' parameter in configuration model" ,
-             object => $self->node,
-            ) unless (defined $auto_create_override ? $auto_create_override : $auto_create );
-
-        $logger->warn("Warning: node '".$self->node->name."' $msg");
-    }
+    Config::Model::Exception::ConfigFile::Missing -> throw (
+         tried_files => \@tried,
+         object => $self->node,
+    ) unless $read_done or $auto_create_override or $auto_create;
 
 }
 
+
+sub read_config_sub_layer {
+    my ($self, $read, $root_dir, $config_file_override, $check, $backend) = @_;
+
+    my $layered_config = delete $read->{default_layer} ;
+    my $layered_read = dclone $read ;
+
+    map { my $lc = delete $layered_config->{$_} ; $layered_read->{$_} = $lc if $lc ;}
+        qw/file config_dir os_config_dir/ ;
+
+    Config::Model::Exception::Model->throw(
+        error => "backend error: unexpected default_layer parameters: "
+          . join( ' ', keys %$layered_config ),
+        object => $self->node,
+    ) if %$layered_config;
+
+    my $i = $self->node->instance ;
+    my $already_in_layered = $i->layered ;
+
+    # layered stuff here
+    if (not $already_in_layered) {
+        $i->layered_clear ;
+        $i->layered_start ;
+    }
+
+    $self->try_read_backend ($layered_read, $root_dir, $config_file_override, $check, $backend);
+
+    if (not $already_in_layered) {
+        $i->layered_stop ;
+    }
+}
+
 # called at configuration node creation, NOT when writing
+#
+# New subroutine "try_read_backend" extracted - Sun Jul 14 11:52:58 2013.
+#
+sub try_read_backend {
+    my $self                 = shift;
+    my $read                 = shift;
+    my $root_dir             = shift;
+    my $config_file_override = shift;
+    my $check                = shift;
+    my $backend              = shift;
+
+    my $read_dir = $read->{os_config_dir}{$^O} || $read->{config_dir} || '';
+    $read_dir .= '/' if $read_dir and $read_dir !~ m(/$);
+
+    my @read_args = (
+        %$read,
+        root        => $root_dir,
+        config_dir  => $read_dir,
+        backend     => $backend,
+        check       => $check,
+        config_file => $config_file_override
+    );
+
+    my ( $file_ok, $res, $fh, $file_path );
+
+    if ( $backend eq 'custom' ) {
+        my $c = my $file = delete $read->{class};
+        $file =~ s!::!/!g;
+        my $f = delete $read->{function} || 'read';
+        require $file . '.pm' unless $c->can($f);
+        no strict 'refs';
+
+        $logger->info("Read with custom backend $ {c}::$f in dir $read_dir");
+
+        ( $file_ok, $file_path, $fh ) = $self->open_read_file(@read_args);
+        eval {
+            $res = &{ $c . '::' . $f }(
+                @read_args,
+                file_path => $file_path,
+                io_handle => $fh,
+                object    => $self->node
+            );
+        };
+    }
+    elsif ( $backend eq 'perl_file' ) {
+        ( $file_ok, $file_path, $fh ) = $self->open_read_file( @read_args, suffix => '.pl' );
+        return (0, $file_path) unless $file_ok;
+        eval { $res = $self->read_perl( @read_args, file_path => $file_path, io_handle => $fh ); };
+    }
+    elsif ( $backend eq 'cds_file' ) {
+        ( $file_ok, $file_path, $fh ) = $self->open_read_file( @read_args, suffix => '.cds' );
+        return (0, $file_path) unless $file_ok;
+        eval {
+            $res = $self->read_cds_file(
+                @read_args,
+                file_path => $file_path,
+                io_handle => $fh,
+            );
+        };
+    }
+    else {
+        # try to load a specific Backend class
+        my $f = delete $read->{function} || 'read';
+        my $c = load_backend_class( $backend, $f ) ;
+        return (0,'unknown') unless defined $c;
+
+        no strict 'refs';
+        my $backend_obj = $c->new( node => $self->node, name => $backend );
+        $self->set_backend( $backend => $backend_obj );
+        my $suffix;
+        $suffix = $backend_obj->suffix if $backend_obj->can('suffix');
+        ( $file_ok, $file_path, $fh ) = $self->open_read_file( @read_args, suffix => $suffix );
+        $logger->info( "Read with $backend " . $c . "::$f on $file_path"  );
+
+        eval {
+            $res = $backend_obj->$f(
+                @read_args,
+                file_path => $file_path,
+                io_handle => $fh,
+                object    => $self->node,
+            );
+        };
+    }
+
+    # catch eval errors done in the if-then-else block before
+    my $e;
+    if ( $e = Exception::Class->caught('Config::Model::Exception::Syntax') ) {
+
+        # FIXME: this is naughty. Should file a bug to add info in rethrow
+        $e->{parsed_file} = $file_path unless $e->parsed_file;
+        $e->rethrow;
+    }
+    elsif ( $e = Exception::Class->caught() ) {
+        ref $e ? $e->rethrow : die $e;
+    }
+
+    return ($res, $file_path);
+}
+
 sub auto_write_init {
     my ($self, %args) = @_ ;
     my $wrlist_orig = delete $args{write_config} ;
@@ -374,7 +437,7 @@ sub auto_write_init {
 
     # w_dir is obsolete
     if (defined $w_dir) {
-        warn $self->config_class_name," : write_config_dir is obsolete\n";
+        die $self->config_class_name," : write_config_dir is obsolete\n";
     }
 
     my $wrlist = dclone $wrlist_orig ;
@@ -400,14 +463,14 @@ sub auto_write_init {
         my $backend = delete $write->{backend} || delete $write->{syntax} || 'custom';
         if ($backend =~ /^(perl|ini|cds)$/) {
             warn $self->config_class_name,
-              " deprecated auto_read backend $backend. Should be '$ {backend}_file'\n";
+              " deprecated backend $backend. Should be '$ {backend}_file'\n";
             $backend .= "_file" ;
         }
 
-        my $write_dir = delete $write->{config_dir} || $w_dir || ''; # w_dir obsolete
+        my $write_dir =  $write->{os_config_dir}{$^O} || $write->{config_dir} || '';
         $write_dir .= '/' if $write_dir and $write_dir !~ m(/$) ; 
 
-        my $fh ;
+        my ($fh, $file_ok) ;
         $fh = new IO::File ; # opened in write callback
 
         $logger->debug("auto_write_init creating write cb ($backend) for ",$self->node->name);
@@ -432,7 +495,7 @@ sub auto_write_init {
                 no strict 'refs';
                 my $file_path ;
                 $logger->debug("write cb ($backend) called for ",$self->node->name);
-                $file_path = $self-> open_file_to_write($backend,$fh,@wr_args,@_) 
+                ($file_ok, $file_path) = $self-> open_file_to_write($backend,$fh,@wr_args,@_)
                     unless ($c->can('skip_open') and $c->skip_open) ;
                 my $res ;
                 $res = eval {
@@ -453,7 +516,7 @@ sub auto_write_init {
         elsif ($backend eq 'perl_file') {
             $wb = sub {
                 $logger->debug("write cb ($backend) called for ",$self->node->name);
-                my $file_path 
+                my ($file_ok, $file_path)
                     = $self-> open_file_to_write($backend,$fh,
                                                 suffix => '.pl',@wr_args,@_) ;
                 my $res ;
@@ -469,7 +532,7 @@ sub auto_write_init {
         elsif ($backend eq 'cds_file') {
             $wb = sub {
                 $logger->debug("write cb ($backend) called for ",$self->node->name);
-                my $file_path 
+                my ($file_ok, $file_path)
                    = $self-> open_file_to_write($backend,$fh,
                                                 suffix => '.cds',@wr_args,@_) ;
                 my $res ;
@@ -494,9 +557,8 @@ sub auto_write_init {
                 my $file_path ;
                 my $suffix ;
                 $suffix = $backend_obj->suffix if $backend_obj->can('suffix');
-                $file_path = $self-> open_file_to_write($backend,$fh,
-                                                         suffix => $suffix,
-                                                         @wr_args,@_) 
+                ($file_ok, $file_path)
+                    = $self-> open_file_to_write($backend,$fh, suffix => $suffix, @wr_args,@_)
                     unless ($c->can('skip_open') and $c->skip_open) ;
                 my $res ;
                 $res = eval {
@@ -521,29 +583,6 @@ sub auto_write_init {
     }
 }
 
-=head2 write_back ( ... )
-
-Try to run all subroutines registered by L<auto_write_init> 
-write the configuration information until one succeeds (returns
-true).
-
-You can specify here a pseudo root directory or another config
-directory to write configuration data back with C<root> and
-C<config_dir> parameters. This will override the model specifications.
-
-You can force to use a backend by specifying C<< backend => xxx >>. 
-For instance, C<< backend => 'augeas' >> or C<< backend => 'custom' >>.
-
-You can force to use all backend to write the files by specifying 
-C<< backend => 'all' >>.
-
-You can force a specific config file to write with 
-C<<config_file => 'foo/bar.conf' >>
-
-C<write_back> will croak if no write call-back are known for this node.
-
-=cut
-
 sub write_back {
     my $self = shift ;
     my %args = @_ ; 
@@ -575,16 +614,24 @@ sub write_back {
 }
 
 sub open_file_to_write {
-    my ($self, $backend, $fh, @args) = @_ ;
+    my ($self, $backend, $fh, %args) = @_ ;
 
-    my $file_path = $self->get_cfg_file_path(@args);
-    if (defined $file_path) {
+    my $backup = delete $args{backup};
+    my $do_backup = defined $backup;
+    $backup ||= 'old'; # use old only if defined
+    $backup = '.'.$backup unless $backup =~ /^\./;
+
+    my ($file_ok, $file_path) = $self->get_cfg_file_path(%args);
+    if ($file_ok) {
+        if ($do_backup and -r $file_path) {
+            copy($file_path, $file_path.$backup) or die "Backup copy failed: $!";
+        }
         $logger->debug("$backend backend opened file $file_path to write");
         $fh ->open("> $file_path") || die "Cannot open $file_path:$!";
         $fh->binmode(':utf8');
     }
 
-    return $file_path ;
+    return ($file_ok, $file_path) ;
 }
 
 sub close_file_to_write {
@@ -667,15 +714,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Load configuration node on demand
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::BackendMgr - Load configuration node on demand
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -783,11 +836,6 @@ for details on the data structure.
 Any format when the user provides a dedicated class and function to
 read and load the configuration tree.
 
-=item augeas
-
-Data can be loaded or stored using RedHat's Augeas library. See
-L<Config::Model::Backend::Augeas> for details.
-
 =back
 
 After loading the data, the object registers itself to the
@@ -808,7 +856,6 @@ mandatory C<config_dir> parameter. For instance:
 If C<file> is not specified, a file name will be constructed with
 C<< <config_class_name>.<suffix> >> where suffix is C<pl> or C<ini> or C<cds>.
 
-
 =head2 Plugin backend classes
 
 A plugin backend class can also be specified with:
@@ -874,9 +921,16 @@ with parameters:
  write       => 1,            # always
  check       => [ yes|no|skip] ,
  root        => $root_dir,
+ backup      => [ undef || '' || suffix ] # backup strategy required by user
 
 Must return 1 if the write was successful, 0 otherwise
 
+If C<io_handle> is defined, the backup has already been done while
+opening the config file. If C<io_handle> is not defined, there's not
+enough information in the model to read the configuration file and
+create the backup. Your write() method will have to do the backup
+requested by user.
+
 =back
 
 =head2 Custom backend
@@ -905,11 +959,35 @@ directory can be hardcoded in the custom class. C<config_dir> beginning
 with 'C<~>' will be munged so C<~> is replaced by C<< File::HomeDir->my_data >>.
 See L<File::HomeDir> for details.
 
+=item os_config_dir
+
+Specify alternate location of a configuration directory depending on the OS
+(as returned by C<$^O>, see L<perlport/PLATFORMS>).
+For instance:
+
+ config_dir => '/etc/ssh',
+ os_config_dir => { darwin => '/etc' }
+
 =item file
 
-optional. This parameter may not apply if the configuration is stored
-in several files. By default, the instance name is used as
-configuration file name. 
+optional. Configuration file. This parameter may not apply if the
+configuration is stored in several files. By default, the instance name
+is used as configuration file name.
+
+=item default_layer
+
+Optional. Specifies where to find a global configuration file that
+specifies default values. For instance, this is used by OpenSSH to
+specify a global configuration file (C</etc/ssh/ssh_config>) that is
+overridden by user's file:
+
+	'default_layer' => {
+            os_config_dir => { 'darwin' => '/etc' },
+            config_dir    => '/etc/ssh',
+            file          => 'ssh_config'
+        }
+
+Only the 3 above parameters can be specified in C<default_layer>.
 
 =item function
 
@@ -944,7 +1022,6 @@ default value for C<function> is C<write>. Here's an example:
                       },
                     ],
 
-
 =head1 Limitations depending on storage
 
 Some storage system will limit the structure of the model you can map
@@ -998,7 +1075,6 @@ A callback to C<Bar::read>. See L</"read callback> for details.
 When a read operation is successful, the remaining read methods will
 be skipped.
 
-
 =head2 write specification
 
 A configuration class will be declared with optional C<write_config>
@@ -1092,7 +1168,6 @@ a graceful migration from a customized format to a C<cds> format.
                   ],
   write_config => [{ backend => 'cds_file', config_dir => '/etc/my_cfg/' }],
 
-
 You can choose also to read and write only customized files:
 
   read_config  => [{ backend => 'custom', class => 'Bar'}],
@@ -1134,6 +1209,29 @@ will be used. For instance:
 In this case, configuration data will be read by C<Bar::read> in
 directory C</etc/foo> and will be written back there by C<Bar::write>.
 
+=head1 Methods
+
+=head2 write_back ( ... )
+
+Try to run all subroutines registered by L<auto_write_init>
+write the configuration information until one succeeds (returns
+true).
+
+You can specify here a pseudo root directory or another config
+directory to write configuration data back with C<root> and
+C<config_dir> parameters. This will override the model specifications.
+
+You can force to use a backend by specifying C<< backend => xxx >>.
+For instance, C<< backend => 'perl_file' >> or C<< backend => 'custom' >>.
+
+You can force to use all backend to write the files by specifying
+C<< backend => 'all' >>.
+
+You can force a specific config file to write with
+C<<config_file => 'foo/bar.conf' >>
+
+C<write_back> will croak if no write call-back are known for this node.
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
@@ -1141,6 +1239,18 @@ Dominique Dumont, (ddumont at cpan dot org)
 =head1 SEE ALSO
 
 L<Config::Model>, L<Config::Model::Instance>,
-L<Config::Model::Node>, L<Config::Model::Dumper>, L<Config::Augeas>
+L<Config::Model::Node>, L<Config::Model::Dumper>
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
