@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,11 +9,11 @@
 #
 package Config::Model::FuseUI ;
 {
-  $Config::Model::FuseUI::VERSION = '2.029';
+  $Config::Model::FuseUI::VERSION = '2.047';
 }
 
 # there's no Singleton with Mouse
-use Any::Moose ;
+use Mouse ;
 
 use Fuse qw(fuse_get_context);
 use Fcntl ':mode';
@@ -183,8 +183,10 @@ sub truncate {
 
     my $v = substr fetch_as_line($obj) , 0, $off ;
 
-    $logger->debug("FuseUI truncate stores '$v'");
-    $obj->store(value => $v, check => 'no') ;
+    $logger->debug("FuseUI truncate stores '$v' of length ",length($v));
+    # store the value without any check. Check will be done in write()
+    # the second parameter will trigger a notif_change.
+    $obj->_store_value( $v, 1 ) ;
     return 0 ;
 }
 
@@ -209,7 +211,7 @@ sub write {
     substr $v,$off,length($buf),$buf ;
     chomp $v unless ($type eq 'leaf' and $obj->value_type eq 'string') ;
     $logger->debug("FuseUI write stores '$v'");
-    $obj->store(value => $v, skip => 'check' ) ;
+    $obj->store(value => $v ) ;
     return length($buf) ;
 }
 
@@ -304,13 +306,21 @@ sub run_loop {
 
 1;
 
+# ABSTRACT: Fuse virtual file interface for Config::Model
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::FuseUI - Fuse virtual file interface for Config::Model
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -332,7 +342,6 @@ version 2.029
  $ui -> run_loop ;  # blocking call
  
  # explore fuse_dir in another terminal then umount fuse_dir directory
- 
 
 =head1 DESCRIPTION
 
@@ -366,7 +375,7 @@ For some configuration, mapping each parameter to a file may lead to a high numb
 
 parameters are:
 
-=over 
+=over
 
 =item model
 
@@ -393,8 +402,20 @@ will perform the mount. Debug parameter is passed to Fuse system to get Fuse tra
 Mount the fuse file system. This method will block until the file system is 
 unmounted (with C<fusermount -u mount_point> command)
 
-=cut
-
 =head1 SEE ALSO
 
 L<Fuse>, L<Config::Model>
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
+=cut
