@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,10 @@
 #
 package Config::Model::IdElementReference;
 {
-  $Config::Model::IdElementReference::VERSION = '2.021';
+  $Config::Model::IdElementReference::VERSION = '2.047';
 }
 
-use Any::Moose;
+use Mouse;
 use namespace::autoclean;
 
 use Carp;
@@ -186,17 +186,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Refer to id element(s) and extract keys
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::IdElementReference - Refer to id element(s) and extract keys
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -302,7 +306,6 @@ version 2.021
  print "master IP is ",$root->grab_value('master_ip'),"\n";
  # prints master IP is 192.168.1.2
 
-
 =head1 DESCRIPTION
 
 This class is user by L<Config::Model::Value> to set up an enumerated
@@ -381,4 +384,16 @@ Dominique Dumont, (ddumont at cpan dot org)
 L<Config::Model>, L<Config::Model::Value>,
 L<Config::Model::AnyId>, L<Config::Model::CheckList>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
