@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::Instance;
 {
-  $Config::Model::Instance::VERSION = '2.040';
+  $Config::Model::Instance::VERSION = '2.047';
 }
 #use Scalar::Util qw(weaken) ;
 
@@ -55,6 +55,12 @@ has check => (
     reader => 'read_check' ,
 ) ;
 
+has auto_create => (
+    is => 'ro',
+    isa => 'Bool',
+    default => 0,
+);
+
 # a unique (instance wise) placeholder for various tree objects
 # to store information
 has _safe => (
@@ -111,6 +117,7 @@ has errors => (
     default => sub { {} },
     handles => {
         _set_error => 'set',
+        cancel_error => 'delete',
         has_error => 'count' ,
         clear_errors => 'clear' ,
         error_paths => 'keys'
@@ -166,7 +173,7 @@ has _write_back => (
 );
 
 # used for auto_read auto_write feature
-has [qw/name root_dir config_file backend backup/] => (
+has [qw/name application root_dir config_file backend backup/] => (
     is => 'ro',
     isa => 'Maybe[Str]' ,
 );
@@ -356,7 +363,7 @@ sub notify_change {
     my $self = shift ;
     my %args = @_ ;
     if ($change_logger->is_debug) {
-        $change_logger->debug("in instance ",$self->name, 'for path ',$args{path}) ;
+        $change_logger->debug("in instance ",$self->name, ' for path ',$args{path}) ;
     }
     $self->add_change( \%args ) ;
     my $cb = $self->on_change_cb ;
@@ -374,7 +381,7 @@ sub list_changes {
         # don't list change without further info (like nodes)
         next unless keys %$c > 1 ;
         my $vt = $c->{value_type} || '' ;
-        my ($o,$n) =  map { $_ || '<undef>' ;} ($c->{old},$c->{new}) ;
+        my ($o,$n) =  map { $_ // '<undef>' ;} ($c->{old},$c->{new}) ;
         
         if ($vt eq 'string' and ($o =~ /\n/ or $n =~ /\n/) ) {
             # append \n if needed so diff works as expected
@@ -434,19 +441,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
+# ABSTRACT: Instance of configuration tree
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.040
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -480,8 +489,6 @@ version 2.040
 
  print $root->describe;
 
-
-
 =head1 DESCRIPTION
 
 This module provides an object that holds a configuration tree. 
@@ -647,7 +654,7 @@ L<Config::Model::Iterator> for details.
 Arguments are explained in  L<Config::Model::Iterator>
 L<constructor arguments|Config::Model::Iterator/"Creating an iterator">.
 
-=head2 
+=head2
 
 =head1 Auto read and write feature
 
@@ -720,4 +727,16 @@ L<Config::Model::Loader>,
 L<Config::Model::Searcher>,
 L<Config::Model::Value>,
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
