@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::ListId ;
 {
-  $Config::Model::ListId::VERSION = '2.040';
+  $Config::Model::ListId::VERSION = '2.047';
 }
 use Mouse ;
 use namespace::autoclean;
@@ -389,18 +389,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Handle list element for configuration model
+
 __END__
 
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::ListId - Handle list element for configuration model
 
 =head1 VERSION
 
-version 2.040
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -454,7 +457,7 @@ Move an element within the list. C<check> can be 'yes' 'no' 'skip'
 
 push some values at the end of the list.
 
-=head2 push_x ( values => [ v1','v2', ...] , [ ... ] )
+=head2 push_x ( values => [ v1','v2', ...] ,  ...  )
 
 Like push with extended options. Options are:
 
@@ -497,9 +500,9 @@ list ref of annotation to store with the list values
 Example:
 
  $elt->push_x (
-    values => [ v1','v2' ] , 
+    values => [ 'v1','v2' ] ,
     annotation => [ 'v1 comment', 'v2 comment' ],
-    check => ''skip'
+    check => 'skip'
  );
 
 =head2 swap ( C<ida> , C<idb> )
@@ -535,4 +538,16 @@ L<Config::Model::AnyId>,
 L<Config::Model::HashId>,
 L<Config::Model::Value>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
