@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,34 +9,9 @@
 #
 package Config::Model::Lister;
 {
-  $Config::Model::Lister::VERSION = '2.021';
+  $Config::Model::Lister::VERSION = '2.047';
 }
 
-=pod
-
-=head1 NAME
-
-Config::Model::Lister - List available models and applications
-
-=head1 VERSION
-
-version 2.021
-
-=head1 SYNOPSIS
-
- perl -MConfig::Model::Lister -e'print Config::Model::Lister::models;'
-
- perl -MConfig::Model::Lister -e'print Config::Model::Lister::applications;'
-
-=head1 DESCRIPTION
-
-Small modules to list available models or applications whose config
-can be edited by L<config-edit>. This module is designed to be used
-by bash completion.
-
-=head1 FUNCTIONS
-
-=cut
 
 use strict;
 use warnings;
@@ -46,37 +21,15 @@ use vars qw/@EXPORT/;
 
 @EXPORT = qw(applications models) ;
 
-=head1 available_models
-
-Returns an array of 3 hash refs:
-
-=over 
-
-=item *
-
-category (system or user or application) => application list. E.g. 
-
- { system => [ 'popcon' , 'fstab'] }
-
-=item *
-
-application => { model => 'model_name', ... }
-
-=item *
-
-application => model_name
-
-=back
-
-=cut
 
 sub available_models {
+    my $test = shift || 0 ;
    
-    my $path = $INC{"Config/Model/Lister.pm"} ;
-    $path =~ s!/Lister\.pm!! ;
     my (%categories, %appli_info, %applications ) ;
+    my %done_cat ;
+    my @dir_to_scan = $test ? qw/lib/ : @INC ;
 
-    foreach my $dir (glob("$path/*.d")) {
+    foreach my $dir (map { glob("$_/Config/Model/*.d") } @dir_to_scan ) {
         my ($cat) = ( $dir =~ m!.*/([\w\-]+)\.d! );
 
         if ($cat !~ /^user|system|application$/) {
@@ -95,7 +48,11 @@ sub available_models {
                 s/#.*// ;
                 my ($k,$v) = split /\s*=\s*/ ;
                 next unless $v ;
-                push @{$categories{$cat}} , $appli if $k =~ /model/i;
+                if ($k =~ /model/i) {
+                    push @{$categories{$cat}} , $appli unless $done_cat{$cat}{$appli} ;
+                    $done_cat{$cat}{$appli} = 1 ;
+                }
+                
                 $appli_info{$appli}{$k} = $v ; 
                 $applications{$appli} = $v if $k =~ /model/i; 
             }
@@ -104,22 +61,12 @@ sub available_models {
     return \%categories, \%appli_info, \%applications ;
 }
 
-=head1 models
-
-Returns a string with the list of models.
-
-=cut
 
 sub models {
     my @i = available_models ;
     return join( ' ',  sort values %{$i[2]} )."\n"; 
 }
 
-=head1 applications
-
-Returns a string with the list of editable applications.
-
-=cut
 
 sub applications {
     my @i = available_models ;
@@ -128,8 +75,66 @@ sub applications {
 
 1;
 
+# ABSTRACT: List available models and applications
+
+__END__
+
 =pod
 
+=encoding UTF-8
+
+=head1 NAME
+
+Config::Model::Lister - List available models and applications
+
+=head1 VERSION
+
+version 2.047
+
+=head1 SYNOPSIS
+
+ perl -MConfig::Model::Lister -e'print Config::Model::Lister::models;'
+
+ perl -MConfig::Model::Lister -e'print Config::Model::Lister::applications;'
+
+=head1 DESCRIPTION
+
+Small modules to list available models or applications whose config
+can be edited by L<config-edit>. This module is designed to be used
+by bash completion.
+
+=head1 FUNCTIONS
+
+=head1 available_models
+
+Returns an array of 3 hash refs:
+
+=over
+
+=item *
+
+category (system or user or application) => application list. E.g.
+
+ { system => [ 'popcon' , 'fstab'] }
+
+=item *
+
+application => { model => 'model_name', ... }
+
+=item *
+
+application => model_name
+
+=back
+
+=head1 models
+
+Returns a string with the list of models.
+
+=head1 applications
+
+Returns a string with the list of editable applications.
+
 =head1 SUPPORT
 
 CPAN RT system, Debian BTS or mailing list.
@@ -138,4 +143,16 @@ CPAN RT system, Debian BTS or mailing list.
 
 Copyright 2011 Dominique Dumont
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
