@@ -1,33 +1,15 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    Copyright (c) 2006-2008,2010 Dominique Dumont.
-#
-#    This file is part of Config-Model.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
 package Config::Model::Loader;
 {
-  $Config::Model::Loader::VERSION = '2.040';
+  $Config::Model::Loader::VERSION = '2.047';
 }
 use Carp;
 use strict;
@@ -38,108 +20,6 @@ use Log::Log4perl qw(get_logger :levels);
 
 my $logger = get_logger("Loader") ;
 
-=head1 NAME
-
-Config::Model::Loader - Load serialized data into config tree
-
-=head1 VERSION
-
-version 2.040
-
-=head1 SYNOPSIS
-
- use Config::Model;
- use Log::Log4perl qw(:easy);
- Log::Log4perl->easy_init($WARN);
-
- # define configuration tree object
- my $model = Config::Model->new;
-  $model->create_config_class(
-    name    => "Foo",
-    element => [
-        [qw/foo bar/] => {
-            type       => 'leaf',
-            value_type => 'string'
-        },
-    ]
- ); 
- 
- $model ->create_config_class (
-    name => "MyClass",
-
-    element => [ 
-
-        [qw/foo bar/] => {
-            type       => 'leaf',
-            value_type => 'string'
-        },
-        hash_of_nodes => {
-            type       => 'hash',     # hash id
-            index_type => 'string',
-            cargo      => {
-                type              => 'node',
-                config_class_name => 'Foo'
-            },
-        },
-        [qw/lista listb/] => { 
-			      type => 'list',
-			      cargo =>  {type => 'leaf',
-					 value_type => 'string'
-					}
-			      },
-    ],
- ) ;
-
- my $inst = $model->instance(root_class_name => 'MyClass' );
-
- my $root = $inst->config_root ;
-
- # put data
- my $step = 'foo=FOO hash_of_nodes:fr foo=bonjour -
-   hash_of_nodes:en foo=hello 
-   ! lista=foo,bar lista:2=baz
-     listb:0=foo listb:1=baz';
- $root->load( step => $step );
-
- print $root->describe,"\n" ;
- # name         value        type         comment                            
- # foo          FOO          string                                          
- # bar          [undef]      string                                          
- # hash_of_nodes <Foo>        node hash    keys: "en" "fr"                    
- # lista        foo,bar,baz  list                                            
- # listb        foo,baz      list                                            
-
-
- # delete some data
- $root->load( step => 'lista~2' );
-
- print $root->describe(element => 'lista'),"\n" ;
- # name         value        type         comment                            
- # lista        foo,bar      list                                            
-
- # append some data
- $root->load( step => q!hash_of_nodes:en foo.=" world"! );
-
- print $root->grab('hash_of_nodes:en')->describe(element => 'foo'),"\n" ;
- # name         value        type         comment                            
- # foo          "hello world" string                                          
-
-=head1 DESCRIPTION
-
-This module is used directly by L<Config::Model::Node> to load
-serialized configuration data into the configuration tree.
-
-Serialized data can be written by the user or produced by
-L<Config::Model::Dumper> while dumping data from a configuration tree.
-
-=head1 CONSTRUCTOR
-
-=head2 new ( )
-
-No parameter. The constructor should be used only by
-L<Config::Model::Node>.
-
-=cut
 
 ## load stuff, similar to grab, but used to set items in the tree
 ## staring from this node
@@ -148,131 +28,6 @@ sub new {
     bless {}, shift ;
 }
 
-=head1 load string syntax
-
-The string is made of the following items (also called C<actions>)
-separated by spaces:
-
-=over 8
-
-=item -
-
-Go up one node
-
-=item !
-
-Go to the root node of the configuration tree.
-
-=item xxx
-
-Go down using C<xxx> element. (For C<node> type element)
-
-=item xxx:yy
-
-Go down using C<xxx> element and id C<yy> (For C<hash> or C<list>
-element with C<node> cargo_type)
-
-=item xxx=~/yy/
-
-Go down using C<xxx> element and loop over the ids that match the regex.
-(For C<hash>)
-
-For instance, with C<OpenSsh> model, you could do
-
- Host=~/.*.debian.org/ user='foo-guest'
-
-to set "foo-user" users for all your debian accounts.
-
-=item xxx~yy
-
-Delete item referenced by C<xxx> element and id C<yy>. For a list,
-this is equivalent to C<splice xxx,yy,1>. This command does not go
-down in the tree (since it has just deleted the element). I.e. a
-'C<->' is generally not needed afterwards.
-
-=item xxx=zz
-
-Set element C<xxx> to value C<yy>. load also accepts to set elements
-with a quoted string. (For C<leaf> element)
-
-For instance C<foo="a quoted string">. Note that you cannot embed
-double quote in this string. I.e C<foo="a \"quoted\" string"> will
-fail.
-
-=item xxx~
-
-Undef element C<xxx>
-
-=item xxx=z1,z2,z3
-
-Set list element C<xxx> to list C<z1,z2,z3>. Use C<,,> for undef
-values, and C<""> for empty values.
-
-I.e, for a list C<('a',undef,'','c')>, use C<a,,"",c>.
-
-=item xxx:yy=zz
-
-For C<hash> element containing C<leaf> cargo_type. Set the leaf
-identified by key C<yy> to value C<zz>.
-
-Using C<xxx=~/yy/=zz> is also possible.
-
-=item xxx.=zzz
-
-Will append C<zzz> value to current values (valid for C<leaf> elements).
-
-=item xxx#zzz or xxx:yyy#zzz
-
-Element annotation. Can be quoted or not quoted. Note that annotations are
-always placed at the end of an action item.
-
-I.e. C<foo#comment>, C<foo:bar#comment> or C<foo:bar=baz#comment> are valid.
-C<foo#comment:bar> is B<not> valid.
-
-=back
-
-=head2 Quotes
-
-You can surround indexes and values with double quotes. E.g.:
-
-  a_string="\"titi\" and \"toto\""
-
-=head1 Methods
-
-=head2 load ( ... )
-
-Load data into the node tree (from the node passed with C<node>)
-and fill values as we go following the instructions passed with
-C<step>.  (C<step> can also be an array ref).
-
-Parameters are:
-
-=over
-
-=item node
-
-node ref of the root of the tree (of sub-root) to start the load from.
-
-=item step
-
-A string or an array ref containing the steps to load. See above for a
-description of the string.
-
-=item experience
-
-Specify the experience level used during the load (default:
-C<master>). The experience can be C<intermediate advanced master>.
-The load will raise an exception if the step of the load string tries
-to access an element with experience higher than user's experience.
-
-=item check
-
-Whether to check values while loading. Either C<yes> (default), C<no> or C<skip>.
-Loading with C<skip> will discard bad values.
-
-=back
-
-=cut
 
 sub load {
     my $self = shift ;
@@ -813,6 +568,239 @@ sub _load_value {
 
 1;
 
+# ABSTRACT: Load serialized data into config tree
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Config::Model::Loader - Load serialized data into config tree
+
+=head1 VERSION
+
+version 2.047
+
+=head1 SYNOPSIS
+
+ use Config::Model;
+ use Log::Log4perl qw(:easy);
+ Log::Log4perl->easy_init($WARN);
+
+ # define configuration tree object
+ my $model = Config::Model->new;
+  $model->create_config_class(
+    name    => "Foo",
+    element => [
+        [qw/foo bar/] => {
+            type       => 'leaf',
+            value_type => 'string'
+        },
+    ]
+ );
+
+ $model ->create_config_class (
+    name => "MyClass",
+
+    element => [
+
+        [qw/foo bar/] => {
+            type       => 'leaf',
+            value_type => 'string'
+        },
+        hash_of_nodes => {
+            type       => 'hash',     # hash id
+            index_type => 'string',
+            cargo      => {
+                type              => 'node',
+                config_class_name => 'Foo'
+            },
+        },
+        [qw/lista listb/] => {
+			      type => 'list',
+			      cargo =>  {type => 'leaf',
+					 value_type => 'string'
+					}
+			      },
+    ],
+ ) ;
+
+ my $inst = $model->instance(root_class_name => 'MyClass' );
+
+ my $root = $inst->config_root ;
+
+ # put data
+ my $step = 'foo=FOO hash_of_nodes:fr foo=bonjour -
+   hash_of_nodes:en foo=hello
+   ! lista=foo,bar lista:2=baz
+     listb:0=foo listb:1=baz';
+ $root->load( step => $step );
+
+ print $root->describe,"\n" ;
+ # name         value        type         comment
+ # foo          FOO          string
+ # bar          [undef]      string
+ # hash_of_nodes <Foo>        node hash    keys: "en" "fr"
+ # lista        foo,bar,baz  list
+ # listb        foo,baz      list
+
+
+ # delete some data
+ $root->load( step => 'lista~2' );
+
+ print $root->describe(element => 'lista'),"\n" ;
+ # name         value        type         comment
+ # lista        foo,bar      list
+
+ # append some data
+ $root->load( step => q!hash_of_nodes:en foo.=" world"! );
+
+ print $root->grab('hash_of_nodes:en')->describe(element => 'foo'),"\n" ;
+ # name         value        type         comment
+ # foo          "hello world" string
+
+=head1 DESCRIPTION
+
+This module is used directly by L<Config::Model::Node> to load
+serialized configuration data into the configuration tree.
+
+Serialized data can be written by the user or produced by
+L<Config::Model::Dumper> while dumping data from a configuration tree.
+
+=head1 CONSTRUCTOR
+
+=head2 new ( )
+
+No parameter. The constructor should be used only by
+L<Config::Model::Node>.
+
+=head1 load string syntax
+
+The string is made of the following items (also called C<actions>)
+separated by spaces:
+
+=over 8
+
+=item -
+
+Go up one node
+
+=item !
+
+Go to the root node of the configuration tree.
+
+=item xxx
+
+Go down using C<xxx> element. (For C<node> type element)
+
+=item xxx:yy
+
+Go down using C<xxx> element and id C<yy> (For C<hash> or C<list>
+element with C<node> cargo_type)
+
+=item xxx=~/yy/
+
+Go down using C<xxx> element and loop over the ids that match the regex.
+(For C<hash>)
+
+For instance, with C<OpenSsh> model, you could do
+
+ Host=~/.*.debian.org/ user='foo-guest'
+
+to set "foo-user" users for all your debian accounts.
+
+=item xxx~yy
+
+Delete item referenced by C<xxx> element and id C<yy>. For a list,
+this is equivalent to C<splice xxx,yy,1>. This command does not go
+down in the tree (since it has just deleted the element). I.e. a
+'C<->' is generally not needed afterwards.
+
+=item xxx=zz
+
+Set element C<xxx> to value C<yy>. load also accepts to set elements
+with a quoted string. (For C<leaf> element)
+
+For instance C<foo="a quoted string">. Note that you cannot embed
+double quote in this string. I.e C<foo="a \"quoted\" string"> will
+fail.
+
+=item xxx~
+
+Undef element C<xxx>
+
+=item xxx=z1,z2,z3
+
+Set list element C<xxx> to list C<z1,z2,z3>. Use C<,,> for undef
+values, and C<""> for empty values.
+
+I.e, for a list C<('a',undef,'','c')>, use C<a,,"",c>.
+
+=item xxx:yy=zz
+
+For C<hash> element containing C<leaf> cargo_type. Set the leaf
+identified by key C<yy> to value C<zz>.
+
+Using C<xxx=~/yy/=zz> is also possible.
+
+=item xxx.=zzz
+
+Will append C<zzz> value to current values (valid for C<leaf> elements).
+
+=item xxx#zzz or xxx:yyy#zzz
+
+Element annotation. Can be quoted or not quoted. Note that annotations are
+always placed at the end of an action item.
+
+I.e. C<foo#comment>, C<foo:bar#comment> or C<foo:bar=baz#comment> are valid.
+C<foo#comment:bar> is B<not> valid.
+
+=back
+
+=head2 Quotes
+
+You can surround indexes and values with double quotes. E.g.:
+
+  a_string="\"titi\" and \"toto\""
+
+=head1 Methods
+
+=head2 load ( ... )
+
+Load data into the node tree (from the node passed with C<node>)
+and fill values as we go following the instructions passed with
+C<step>.  (C<step> can also be an array ref).
+
+Parameters are:
+
+=over
+
+=item node
+
+node ref of the root of the tree (of sub-root) to start the load from.
+
+=item step
+
+A string or an array ref containing the steps to load. See above for a
+description of the string.
+
+=item experience
+
+Specify the experience level used during the load (default:
+C<master>). The experience can be C<intermediate advanced master>.
+The load will raise an exception if the step of the load string tries
+to access an element with experience higher than user's experience.
+
+=item check
+
+Whether to check values while loading. Either C<yes> (default), C<no> or C<skip>.
+Loading with C<skip> will discard bad values.
+
+=back
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
@@ -821,4 +809,16 @@ Dominique Dumont, (ddumont at cpan dot org)
 
 L<Config::Model>,L<Config::Model::Node>,L<Config::Model::Dumper>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
