@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,10 @@
 #
 package Config::Model::Node;
 {
-  $Config::Model::Node::VERSION = '2.021';
+  $Config::Model::Node::VERSION = '2.047';
 }
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Carp ;
@@ -47,7 +47,7 @@ my %legal_properties = (
                        ) ;
 
 my $logger = get_logger("Tree::Node") ;
-
+my $fix_logger = get_logger("Anything::Fix") ;
 
 # Here are the legal element types
 my %create_sub_for = 
@@ -102,8 +102,7 @@ sub _config_model {
 }
 
 has skip_read => ( is => 'ro', isa => 'Bool') ;
-has check => ( is => 'ro', isa => 'Str', builder => '_check_check', lazy => 1) ;
-has auto_read => ( is => 'rw' , isa => 'HashRef' ) ;
+has check => ( is => 'ro', isa => 'Str', default => 'yes') ;
 has model => ( is => 'rw' , isa => 'HashRef' ) ;
 has needs_save => ( is => 'rw', isa => 'Bool', default => 0 ) ;
 
@@ -120,15 +119,14 @@ sub BUILD {
               :                                                 'yes' ;
     
     
-    $self->auto_read( { skip => $self->skip_read, check => $check } );
-    
     my $caller_class = defined $self->parent 
       ? $self->parent->name : 'user' ;
 
     my $class_name = $self->config_class_name ;
     $logger->info( "New $class_name requested by $caller_class");
 
-    $self->model( dclone ( $self->config_model->get_model($class_name) ) );
+    # get_model returns a cloned data structure
+    $self->model( $self->config_model->get_model($class_name) );
         
     $self->check_properties ;
 
@@ -146,15 +144,19 @@ sub create_element {
 
     my $element_info = $self->{model}{element}{$element_name}  ;
 
-    return if $check eq 'skip' and not defined $element_info;
-     
-    Config::Model::Exception::UnknownElement->throw(
-                                                    object   => $self,
-                                                    function => 'create_element',
-                                                    where    => $self->location || 'configuration root',
-                                                    element     => $element_name,
-                                                   )
-        unless defined $element_info ;
+    if ( not defined $element_info ) {
+        if ( $check eq 'yes' ) {
+            Config::Model::Exception::UnknownElement->throw(
+                object   => $self,
+                function => 'create_element',
+                where    => $self->location || 'configuration root',
+                element  => $element_name,
+            );
+        }
+        else {
+            return;    # just skip when check is no or skip
+        }
+    }
 
     Config::Model::Exception::Model->throw
         (
@@ -351,12 +353,8 @@ sub init {
     
     $self->{backend_mgr} ||= Config::Model::BackendMgr->new( node => $self );
 
-    my $ar = $self->{auto_read};
-
-    my $check = $ar->{check};
-    if ( defined $model->{read_config} and not $ar->{skip_read} ) {
-        $ar->{done} = 1;
-        $self->read_config_data(check => $check) ;
+    if ( defined $model->{read_config} and not $self->skip_read ) {
+        $self->read_config_data(check => $self->check) ;
     }
 
     # use read_config data if write_config is missing
@@ -392,7 +390,7 @@ sub read_config_data {
         check           => $args{check},
         read_config_dir => $model->{read_config_dir},
         config_file     => $args{config_file} || $self->{config_file},
-        auto_create     => $args{auto_create} ,
+        auto_create     => $args{auto_create} || $self->instance->auto_create,
     );
 }
 
@@ -484,6 +482,9 @@ sub find_element {
     my ($self,$name, %args ) = @_ ;
     croak "find_element: missing element name" unless defined $name ;
 
+    # should be the case if people are using cme edit
+    return $name if defined $self->{model}{element}{$name} ;
+
     # look for a close element playing with cases;
     if (defined $args{case} and $args{case} eq 'any') {
         foreach my $elt (keys %{$self->{model}{element}}) {
@@ -726,26 +727,27 @@ sub fetch_element {
       = $self->get_element_property(property => 'level',
                                     element  => $element_name) ;
 
-    if ($element_level eq 'hidden' and not $accept_hidden) {
-        Config::Model::Exception::UnavailableElement
-            ->throw(
-                    object   => $self,
-                    element  => $element_name,
-                    info     => 'hidden element',
-                   );
+    if ( $element_level eq 'hidden' and not $accept_hidden ) {
+        return 0 if ( $check eq 'no' or $check eq 'skip' );
+        Config::Model::Exception::UnavailableElement->throw(
+            object  => $self,
+            element => $element_name,
+            info    => 'hidden element',
+        );
     }
 
 
     # check status
-    if ($self->{status}{$element_name} eq 'obsolete') {
+    if ( $self->{status}{$element_name} eq 'obsolete' ) {
+
         # obsolete is a status not very different from a missing
         # item. The only difference is that user will get more
         # information
-        Config::Model::Exception::ObsoleteElement
-            ->throw(
-                    object   => $self,
-                    element  => $element_name,
-                   );
+        return 0 if ( $check eq 'no' or $check eq 'skip' );
+        Config::Model::Exception::ObsoleteElement->throw(
+            object  => $self,
+            element => $element_name,
+        );
     }
 
     if ($self->{status}{$element_name} eq 'deprecated' 
@@ -981,8 +983,6 @@ sub load {
     my %args = @_ eq 1 ? (step => $_[0]) : @_ ;
     if (defined $args{step}) {
         $loader->load(node => $self, %args) ;
-#    } elsif (defined $args{ref}) {
-#        $self->load_data($args{ref}) ; # 
     }
     else {
         Config::Model::Exception::Load
@@ -994,10 +994,21 @@ sub load {
 }
 
 sub load_data {
-    my $self                = shift ;
-    my $raw_perl_data       = shift ;
+    my $self = shift ;
 
-    my $check = $self->_check_check(shift) ;
+    if (@_ == 3) {
+        # kludge to avoid breaking Config::Model::Itself. Should be removed end of 2013
+        carp "load_data called with even number of parameters. Use named parameters" ;
+    } ;
+
+
+    my %args
+        = @_ == 3 ? ( data => $_[0], check => $_[2]) # should also be removed end of 2013
+        : @_ > 1 ? @_
+        : ( data => shift) ;
+
+    my $raw_perl_data       = delete $args{data};
+    my $check = $self->_check_check($args{check}) ;
 
     if (    not defined $raw_perl_data 
         or (ref($raw_perl_data) ne 'HASH' 
@@ -1034,8 +1045,19 @@ sub load_data {
             my $obj = $self->fetch_element(name => $elt, experience => 'master', 
                                            check => $check) ;
 
-            $obj -> load_data(delete $perl_data->{$elt}) ;
-        } elsif ($check ne 'skip')  {
+            if ($obj) {
+                $obj -> load_data(%args, data => delete $perl_data->{$elt}) ;
+            }
+            elsif (defined $obj) {
+                # skip hidden elements and trash corresponding data
+                $logger->trace("Node load_data drop element $elt");
+                delete $perl_data->{$elt};
+            }
+
+        } elsif ($check eq 'skip')  {
+            $logger->trace("Node load_data skips element $elt");
+        }
+        else {
             Config::Model::Exception::LoadData 
                 -> throw (
                           message => "load_data: tried to load hidden "
@@ -1049,13 +1071,15 @@ sub load_data {
 
     # Load elements matched by accept parameter
     if (defined $self->{model}{accept}) {
-        #Now, $perl_data contains all elements not yet parsed
-        foreach my $elt (keys %$perl_data) {
+        # Now, $perl_data contains all elements not yet parsed
+        # sort is required to have a predictable order of accepted elements
+        foreach my $elt (sort keys %$perl_data) {
             #load value
             #TODO: annotations
             my $obj = $self->fetch_element(name => $elt, experience => 'master', check => $check) ;
+            next unless $obj; # in cas of known but unavailable elements
             $logger->debug("Node load_data: accepting element $elt");
-            $obj ->load_data(delete $perl_data->{$elt}) if defined $obj;
+            $obj ->load_data(%args, data => delete $perl_data->{$elt}) if defined $obj;
             }
     }
 
@@ -1083,7 +1107,7 @@ sub dump_tree {
 sub migrate {
     my $self = shift ;
     $self->init ;
-    Config::Model::Dumper->new->dump_tree(node => $self, mode => 'custom', @_) ;
+    Config::Model::Dumper->new->dump_tree(node => $self, mode => 'full', @_) ;
 
     return $self->needs_save ;
 }
@@ -1126,10 +1150,12 @@ sub audit {
 
 sub copy_from {
     my $self = shift ;
-    my $from = shift ;
+    my %args = @_ > 1 ? @_ : (from => shift) ;
+    my $from = $args{from} || croak "copy_from: missing from argument";
+    my $check = $args{check} || 'yes' ;
     $logger->debug("node ".$self->location." copy from ".$from->location);
     my $dump = $from->dump_tree(check => 'no') ;
-    $self->load( step => $dump, check => 'skip' ) ;
+    $self->load( step => $dump, check => $check ) ;
 }
 
 
@@ -1162,22 +1188,68 @@ sub tree_searcher {
     return Config::Model::TreeSearcher->new ( node => $self, @_ );
 }
 
+sub apply_fixes {
+    my $self = shift ;
+    my $filter = shift || '.';
+
+    # define leaf call back
+    my $fix_leaf = sub { 
+      my ($scanner, $data_ref, $node,$element_name,$index, $leaf_object) = @_ ;
+      $leaf_object->apply_fixes if $element_name =~ /$filter/ ;
+    } ;
+
+    my $fix_hash = sub {
+        my ( $scanner, $data_r, $node, $element, @keys ) = @_;
+
+        return unless @keys;
+
+        # leaves must be fixed before the hash, hence the 
+        # calls to scan_hash before apply_fixes
+        map {$scanner->scan_hash($data_r,$node,$element,$_)} @keys ;
+
+        $node->fetch_element($element)->apply_fixes if $element =~ /$filter/ ;
+    } ;
+    
+    my $fix_list = sub {
+        my ( $scanner, $data_r, $node, $element, @keys ) = @_;
+
+        return unless @keys;
+
+        map {$scanner->scan_list($data_r,$node,$element,$_)} @keys ;
+        $node->fetch_element($element)->apply_fixes if $element =~ /$filter/ ;
+    } ;
+    
+   my $scan = Config::Model::ObjTreeScanner-> new ( 
+        hash_element_cb => $fix_hash ,
+        list_element_cb => $fix_list ,
+        leaf_cb => $fix_leaf ,
+        check => 'no',
+    ) ;
+
+    $fix_logger->debug("apply fix started from ",$self->name) ;
+    $scan->scan_node(undef, $self) ;
+    $fix_logger->debug("apply fix done") ;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Class for configuration tree node
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -1352,7 +1424,7 @@ configuration files.
 =item B<config_dir>
 
 Parameters used to load on demand configuration data. 
-See L<Config::Model::AutoRead> for details.
+See L<Config::Model::BackendMgr> for details.
 
 =item B<accept>
 
@@ -1398,8 +1470,7 @@ Example:
 
 The model snippet above will ensure that C<Bug-Debian> will be shown right after C<bug>.
 
-=for html
-<p>For more information, see <a href="http://ddumont.wordpress.com/2010/05/19/improve-config-upgrade-ep-02-minimal-model-for-opensshs-sshd_config/">this blog<\a>.</p>
+=for html <p>For more information, see <a href="http://ddumont.wordpress.com/2010/05/19/improve-config-upgrade-ep-02-minimal-model-for-opensshs-sshd_config/">this blog</a>.</p>
 
 =back
 
@@ -1670,7 +1741,8 @@ If user_experience is given, this method will check that the user has
 enough privilege to access the element. If not, a C<RestrictedElement>
 exception will be raised.
 
-check can be set to yes, no or skip
+check can be set to yes, no or skip. When check is C<no> or C<skip>, can return C<undef> when the
+element is unknown, or 0 if the element is not available (hidden).
 
 =head2 fetch_element_value ( name => ... [ check => ...] )
 
@@ -1692,7 +1764,6 @@ exception will be raised.
 
 =head2 is_element_available( name => ...,  experience => ... )
 
-
 Returns 1 if the element C<name> is available for the given
 C<experience> ('beginner' by default) and if the element is
 not "hidden". Returns 0 otherwise.
@@ -1728,7 +1799,6 @@ See L<Config::Model::AnyThing/"grab(...)">.
 
 See L<Config::Model::AnyThing/"grab_value(...)">.
 
-
 =head2 grab_root()
 
 See L<Config::Model::AnyThing/"grab_root()">.
@@ -1749,6 +1819,11 @@ Set a value from a directory like path.
 Force a read of the configuration and perform all changes regarding 
 deprecated elements or values. Return 1 if data needs to be saved.
 
+=head2 apply_fixes
+
+Scan the tree from this node and apply fixes that are attached to warning specifications. 
+See C<warn_if_match> or C<warn_unless_match> in L<Config::Model::Value/>.
+
 =head2 load ( step => string [, experience => ... ] )
 
 Load configuration data from the string into the node and its siblings.
@@ -1761,12 +1836,16 @@ This method can also be called with a single parameter:
 
   $node->load("some data:to be=loaded");
 
-=head2 load_data ( hash_ref, [ $check  ])
+=head2 load_data ( data => hash_ref, [ check => $check, ...  ])
 
-Load configuration data with a hash ref (first parameter). The hash ref key must match
-the available elements of the node. The hash ref structure must match
+Load configuration data with a hash ref. The hash ref key must match
+the available elements of the node (or accepted element). The hash ref structure must match
 the structure of the configuration model.
 
+Use C<< check => skip >> to make data loading more tolerant: bad data will be discarded.
+
+C<load_data> can be called with a single hash ref parameter.
+
 =head2 needs_save
 
 return 1 if one of the elements of the node's sub-tree has been modified.
@@ -1802,11 +1881,12 @@ Provides a text audit on the content of the configuration below this
 node. This audit will show only value different from their default
 value.
 
-=head2 copy_from ( another_node_object )
+=head2 copy_from ( from => another_node_object, [ check => ... ] )
 
 Copy configuration data from another node into this node and its
-siblings. The copy is made in a I<tolerant> mode where invalid data
-are simply discarded.
+siblings. The copy can be made in a I<tolerant> mode where invalid data
+is discarded with C<< check => skip >>. This method can be called with
+a single argument: C<< copy_from($another_node) >>
 
 =head1 Help management
 
@@ -1841,10 +1921,10 @@ Typically, you will have to call C<search> on this object.
 
 Returns a L<Config::Model::TreeSearcher> object.
 
-=head2 AutoRead nodes
+=head2 Lazy load of node data
 
 As configuration model are getting bigger, the load time of a tree
-gets longer. The L<Config::Model::AutoRead> class provides a way to
+gets longer. The L<Config::Model::BackendMgr> class provides a way to
 load the configuration information only when needed.
 
 =head1 AUTHOR
@@ -1861,4 +1941,16 @@ L<Config::Model::CheckList>,
 L<Config::Model::WarpedNode>,
 L<Config::Model::Value>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
