@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,11 +9,11 @@
 #
 package Config::Model::TreeSearcher ;
 {
-  $Config::Model::TreeSearcher::VERSION = '2.011';
+  $Config::Model::TreeSearcher::VERSION = '2.047';
 }
 
-use Any::Moose ;
-use Any::Moose '::Util::TypeConstraints';
+use Mouse ;
+use Mouse::Util::TypeConstraints;
 use namespace::autoclean;
 
 use Log::Log4perl qw(get_logger :levels);
@@ -27,7 +27,7 @@ enum ('SearchType' =>  [ @search_types, 'all' ]);
 # clean up namespace to avoid clash between MUTC keywords and
 # my functions
 # See http://www.nntp.perl.org/group/perl.moose/2010/10/msg1935.html
-no Any::Moose '::Util::TypeConstraints';
+no Mouse::Util::TypeConstraints;
 
 has 'node'  => ( is => 'ro', isa => 'Config::Model::Node' , 
                   weak_ref => 1, required => 1 );
@@ -137,13 +137,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT: Search tree for match in value, description...
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::TreeSearcher - Search tree for match in value, description...
 
 =head1 VERSION
 
-version 2.011
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -197,7 +205,7 @@ a value, a description or anything that match the given pattern (or keyword).
 
 Creates a new searcher object. The C<type> parameter can be:
 
-=over 
+=over
 
 =item element 
 
@@ -240,5 +248,17 @@ Dominique Dumont, (ddumont at cpan dot org)
 L<Config::Model>,
 L<Config::Model::SearchElement>,
 L<Config::Model::AnyThing>
- 
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
