@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,16 +9,18 @@
 #
 package Config::Model::Value ;
 {
-  $Config::Model::Value::VERSION = '2.029';
+  $Config::Model::Value::VERSION = '2.047';
 }
 
 use 5.10.1 ;
 
-use Any::Moose;
-use Any::Moose '::Util::TypeConstraints' ;
-use Any::Moose 'X::StrictConstructor' ;
+use Mouse;
+use Mouse::Util::TypeConstraints;
+use MouseX::StrictConstructor;
 use namespace::autoclean;
 
+use Parse::RecDescent 1.90.0;
+
 use Data::Dumper ();
 use Config::Model::Exception ;
 use Config::Model::ValueComputer ;
@@ -28,10 +30,12 @@ use Log::Log4perl qw(get_logger :levels);
 use Scalar::Util qw/weaken/ ;
 use Carp ;
 use Storable qw/dclone/;
+use AnyEvent ;
 
 extends qw/Config::Model::AnyThing/ ;
 
 my $logger = get_logger("Tree::Element::Value") ;
+my $async_logger = get_logger("Async::Value") ;
 my $change_logger = get_logger("Anything::Change") ;
 my $fix_logger = get_logger("Anything::Fix") ;
 
@@ -89,6 +93,59 @@ sub _compute_is_default {
     return ! $self->compute_obj->use_as_upstream_default ;
 }
 
+has _pending_store => (
+    traits  => ['Counter'],
+    is      => 'ro',
+    isa     => 'Int',
+    default => 0,
+    handles => {
+        inc_pending_store   => 'inc',
+        dec_pending_store   => 'dec',
+    },
+    trigger => sub {
+        my ($self,$count) = @_ ;
+        my $cb = $self->_pending_fetch or return ;
+        return if $count ;
+        $cb->() ;
+        $self->_fetch_done;
+    }
+);
+
+has _pending_fetch => (
+    is => 'rw',
+    isa => 'Maybe[CodeRef]',
+    clearer => '_fetch_done'
+);
+
+has error_list => (
+    is => 'ro',
+    isa => 'ArrayRef',
+    default => sub { [] },
+    traits => ['Array'] ,
+    handles => {
+        add_error => 'push',
+        clear_errors  => 'clear',
+        error_msg => [ join => "\n\t" ],
+        has_error => 'count',
+        all_errors => 'elements' ,
+        is_ok => 'is_empty'
+    }
+) ;
+
+has warning_list => (
+    is => 'ro',
+    isa => 'ArrayRef',
+    default => sub { [] },
+    traits => ['Array'] ,
+    handles => {
+        add_warning => 'push',
+        clear_warnings  => 'clear',
+        warning_msg => [ join => "\n\t" ],
+        has_warning => 'count',
+        all_warnings => 'elements' ,
+    }
+) ;
+
 # as some information like experience must be backed up even though they are not
 # attributes, we cannot move below code in BUILD. (experience is actually used by node)
 around BUILDARGS => sub {
@@ -126,9 +183,14 @@ sub notify_change {
     return if $self->instance->initial_load and not $args{really};
     
     $change_logger->debug("called while needs_check is ",$self->needs_check,
-	" for ",$self->name) 
+	" for ",$self->name, " with ", join(' ',%args))
 	if $change_logger->is_debug ;
     $self->needs_check(1) unless $check_done;
+    {
+        no warnings 'uninitialized';
+        croak "needless change with $args{new}" if defined $args{old}
+            and defined $args{new} and $args{old} eq $args{new} ;
+    }
     $self->SUPER::notify_change(%args, value_type => $self->value_type) ;
 
     # notify all warped or computed objects that depends on me 
@@ -164,13 +226,14 @@ sub set_default {
 	my $def    = delete $arg_ref->{$item} ;
 
 	next unless defined $def ;
+        $self->transform_boolean(\$def) if $self->value_type eq 'boolean';
 
 	# will check default value
-	my @error = $self->check_value(value => $def) ;
+	$self->check_value(value => $def) ;
 	Config::Model::Exception::Model->throw(
 	    object => $self,
-	    error  => "Wrong $item value\n\t" . join( "\n\t", @error )
-	) if @error;
+	    error  => "Wrong $item value\n\t" . $self->error_msg
+	) if $self->has_error;
 
 	$logger->debug( "Set $item value for ", $self->name, "" );
 
@@ -236,11 +299,11 @@ sub perform_compute {
     #print "compute: result $result\n" ;
     # check if the computed result fits with the constraints of the
     # Value object
-    my $ok = $self->check_value($result) ;
+    my $ok = $self->check_fetched_value($result) ;
 
     #print "check result: $ok\n";
     if (not $ok) {
-        my $error =  join("\n\t",@{$self->{error_list}}) .
+        my $error =  $self->error_msg.
           "\n\t".$self->compute_info;
 
         Config::Model::Exception::WrongValue
@@ -311,7 +374,7 @@ sub migrate_value {
 
     #print "check result: $ok\n";
     if (not $ok) {
-        my $error =  join("\n\t",@{$self->{error_list}}) .
+        my $error =  $self->error_msg .
           "\n\t".$self->{_migrate_from}->compute_info;
 
         Config::Model::Exception::WrongValue
@@ -760,20 +823,6 @@ sub get_help {
     return ;
 }
 
-
-sub error_msg {
-    my $self = shift ;
-    return unless $self->{error_list} ;
-    return wantarray ? @{$self->{error_list}} : join("\n\t",@{ $self ->{error_list}}) ;
-}
-
-
-sub warning_msg {
-    my $self = shift ;
-    return unless $self->{warning_list} ;
-    return wantarray ? @{$self->{warning_list}} : join("\n",@{ $self ->{warning_list}})
-}
-
 # construct an error message for enum types
 sub enum_error {
     my ($self,$value) = @_ ;
@@ -798,17 +847,18 @@ sub enum_error {
     return @error ;
 }
 
-
+# asynchronous if a call-back is passed
 sub check_value {
     my $self = shift ;
-    croak "check_value needs a value to check" unless @_ ;
-    
-    my %args = @_ > 1 ? @_ : (value => $_[0]) ;
+    croak "check_value needs a value to check" unless @_ > 1;
+
+    my %args = @_ ;
     my $value = $args{value} ;
     my $quiet = $args{quiet} || 0 ;
     my $check = $args{check} || 'yes' ;
     my $apply_fix = $args{fix} || 0 ;
     my $mode = $args{mode} || 'backend' ;
+    my $cb = delete $args{callback} ;
 
     #croak "Cannot specify a value with fix = 1" if $apply_fix and exists $args{value} ;
 
@@ -910,19 +960,19 @@ sub check_value {
     if ($mode ne 'custom') {
         if ($self->{warn_if_match}) {
             my $test_sub = sub {my ($v,$r) = @_ ; $v =~ /$r/ ? 0 : 1;} ;
-            $self->run_regexp_set_on_value($value, $apply_fix, \@warn, 'not ',$test_sub, $self->{warn_if_match}) ; 
+            $self->run_regexp_set_on_value(\$value, $apply_fix, \@warn, 'not ',$test_sub, $self->{warn_if_match}) ; 
         }
     
         if ($self->{warn_unless_match}) {
             my $test_sub = sub {my ($v,$r) = @_ ; $v =~ /$r/ ? 1 : 0 ;} ;
-            $self->run_regexp_set_on_value($value, $apply_fix, \@warn, '',$test_sub, $self->{warn_unless_match}) ; 
+            $self->run_regexp_set_on_value(\$value, $apply_fix, \@warn, '',$test_sub, $self->{warn_unless_match}) ; 
         }
     
-        $self->run_code_set_on_value( $value, $apply_fix, \@error,
+        $self->run_code_set_on_value( \$value, $apply_fix, \@error,
             "assert failure",
             $self->{assert} )
           if $self->{assert};
-        $self->run_code_set_on_value( $value, $apply_fix, \@warn,
+        $self->run_code_set_on_value( \$value, $apply_fix, \@warn,
             "warn_unless code check returned false",
             $self->{warn_unless} )
           if $self->{warn_unless};
@@ -944,19 +994,25 @@ sub check_value {
     }
 
     $logger->debug("check_value returns ",scalar @error," errors and ", scalar @warn," warnings");
-    $self->{error_list} = \@error ;
-    $self->{warning_list} = \@warn ;
+    $self->clear_errors;
+    $self->clear_warnings;
+    $self->add_error( @error ) if @error;
+    $self->add_warning( @warn ) if @warn;
+
+    $args{value} = $value ; # may be updated by apply_fix
 
     $logger->debug("done") ;
-    return wantarray ? @error : scalar @error ? 0 : 1 ;
+
+    $cb->(%args, ok => not @error) if $cb ;
+    return not @error ;
 }
 
 sub run_code_on_value {
-    my ($self,$value, $apply_fix, $array, $label, $sub, $msg, $fix) = @_;
+    my ($self,$value_r, $apply_fix, $array, $label, $sub, $msg, $fix) = @_;
 
     $logger->info( $self->location . ": run_code_on_value called (apply_fix $apply_fix)" );
 
-    my $ret = $sub->($value) ;
+    my $ret = $sub->($$value_r) ;
     if ($logger->is_debug) {
         my $str = defined $ret ? $ret : '<undef>';
         $logger->debug( "run_code_on_value sub returned '$str'" );
@@ -966,12 +1022,12 @@ sub run_code_on_value {
         $logger->debug( "run_code_on_value sub returned false" );
         push @$array, $msg unless $apply_fix ;
         $self->{nb_of_fixes}++ if (defined $fix and not $apply_fix);
-        $self->apply_fix($fix,$value) if (defined $fix and $apply_fix);
+        $self->apply_fix($fix,$value_r) if (defined $fix and $apply_fix);
     }
 }
 
 sub run_code_set_on_value {
-    my ($self,$value, $apply_fix, $array, $msg, $w_info) = @_ ; ; 
+    my ($self,$value_r, $apply_fix, $array, $msg, $w_info) = @_ ;
         
     foreach my $label ( keys %$w_info ) {
         my $code = $w_info->{$label}{code} ;
@@ -991,21 +1047,21 @@ sub run_code_set_on_value {
             return $ret ;
         };
         
-        $self->run_code_on_value($value,$apply_fix,$array,$label,$sub,$msg,$fix) ;
+        $self->run_code_on_value($value_r,$apply_fix,$array,$label,$sub,$msg,$fix) ;
     }
 }
 
 sub run_regexp_set_on_value {
-    my ($self,$value, $apply_fix, $array, $msg, $test_sub, $w_info) = @_ ; ; 
+    my ($self,$value_r, $apply_fix, $array, $msg, $test_sub, $w_info) = @_ ;
 
     # no need to check default or computed values
-    return unless defined $value;
+    return unless defined $$value_r;
 
     foreach my $rxp ( keys %$w_info ) {
         my $sub = sub { $test_sub->($_[0], $rxp) } ;
-        my $msg = $w_info->{$rxp}{msg} || "value '$value' should $msg"."match regexp $rxp";
+        my $msg = $w_info->{$rxp}{msg} || "value '$$value_r' should $msg"."match regexp $rxp";
         my $fix = $w_info->{$rxp}{fix} ;
-        $self->run_code_on_value($value,$apply_fix,$array,'regexp',$sub,$msg,$fix) ;
+        $self->run_code_on_value($value_r,$apply_fix,$array,'regexp',$sub,$msg,$fix) ;
     }
 }
     
@@ -1023,16 +1079,42 @@ sub apply_fixes {
         $fix_logger->debug( "called for ".$self->location ) ;
     }
 
-    $self->check_value(value => $self->{data}, fix => 1);
-    # $self->notify_change ;
+    # a fix may use async store. So check after fix must be asynchronous
+    my ($old, $new) ;
+    my $i = 0;
+
+    my $check_fix ;
+    my $try = sub {
+        $old = $self->{nb_of_fixes} ;
+        $self->check_value(value => $self->{data}, fix => 1, callback => $check_fix);
+    };
+
+    $check_fix = sub {
+        $new = $self->{nb_of_fixes} ;
+        $self->check_value(value => $self->{data}); # this is synchronous
+        if ($i++ > 100) {
+            Config::Model::Exception::Model->throw(
+                object => $self,
+                error  => "Too many fix loops: check with fix code or regexp"
+            ) ;
+        }
+        elsif ($self->{nb_of_fixes} and $old > $new) {
+            $try->() ;
+        }
+        else {
+            undef $try; # avoid leak
+        }
+    } ;
+    $try->() ;
+
 }
 
 
 # internal: called by check when a fix is required
 sub apply_fix {
-    my ( $self, $fix, $value ) = @_;
+    my ( $self, $fix, $value_r ) = @_;
 
-    local $_ = $value; # used inside $fix sub ref
+    local $_ = $$value_r; # used inside $fix sub ref
 
     if ($fix_logger->is_debug){ 
 	my $str = $fix ;
@@ -1048,29 +1130,44 @@ sub apply_fix {
         );
     }
 
-    $self->{data}  = $_ ;
+    no warnings "uninitialized";
+    $self->_store_fix($$value_r, $_) if ($_ ne $$value_r);
+}
+
+sub _store_fix {
+    my ( $self, $old, $new ) = @_;
+
+    $self->{data} = $new ;
 
     if ($fix_logger->is_trace){ 
-	$fix_logger->trace( "fix change: '" . ($value // '<undef>') ."' -> '"
-	    . ($self->{data} // '<undef>'). "'" );
+	$fix_logger->trace( "fix change: '" . ($old // '<undef>') ."' -> '"
+	    . ($new // '<undef>'). "'" );
     }
     
     $self->notify_change(
-        old => $value // $self->_fetch_std, 
-        new => $self->{data} // $self->_fetch_std,
+        old => $old // $self->_fetch_std,
+        new => $new // $self->_fetch_std,
         note => 'applied fix'
     ) ;
     # $self->store(value => $_, check => 'no');  # will update $self->{fixes}
 }
 
+# read checks should be blocking
+# store checks should be async
+
 
 sub check {
+    goto &check_fetched_value ;
+}
+
+sub check_fetched_value {
     my $self = shift;
 
-    $logger->debug(
-        "called for " . $self->location . " from " . join( ' ', caller ),
-        " with @_" )
-      if $logger->is_debug;
+    if ($logger->is_debug) {
+        no warnings 'uninitialized' ;
+        $logger->debug( "called for " . $self->location
+            . " from " . join( ' ', caller ), " with @_" );
+    }
 
     my %args =
         @_ == 0 ? ( value => $self->{data} )
@@ -1081,31 +1178,45 @@ sub check {
     my $silent = $args{silent} || 0;
     my $check = $args{check} || 'yes' ;
 
-    if ($self->needs_check) {
-	my @error = $self->check_value(%args);
+    if ($self->_pending_store) {
+        my $w = AnyEvent->condvar ;
+        $async_logger->debug("blocks on pending store, count: ", $self->_pending_store);
+        $self->_pending_fetch( sub { $w->send; }) ;
+        $w->recv ;
+        $async_logger->debug("unblocked after pending store");
+    }
 
-	$self->{error_list} = \@error;
-	$logger->debug("check done");
+    if ($self->needs_check) {
+        my $w = AnyEvent->condvar ;
+        my $cb = sub { $w->send } ;
+
+	$self->check_value(%args, callback => $cb );
+
+        $async_logger->debug("blocks on check_value");
+        $w->recv ;
+        $async_logger->debug("unblocked after check_value");
+
+	my $err_count = $self->has_error;
+	my $warn_count = $self->has_warning;
+	$logger->debug("done with $err_count errors and $warn_count warnings");
 
 	# some se case like idElementReference are too complex to propagate
 	# a change notification back to the value using them. So an error or
 	# warning must always be rechecked.
-	my $warn = $self->{warning_list};
-	$self->needs_check(0) unless @error or @$warn ;
+	$self->needs_check(0) unless $err_count or $warn_count ;
     }	
     else {
-	$logger->debug("check is not needed");
+	$logger->debug("is not needed");
     }
 
-    my $warn = $self->{warning_list};
-    
     # old_warn is used to avoid warning the user several times for the 
     # same reason. We take care to clean up this hash each time this routine
     # is run
     my $old_warn = $self->{old_warning_hash} || {} ;
     my %warn_h ;
-    if (@$warn and not $nowarning and not $silent) {
-        foreach my $w (@$warn) {
+
+    if ($self->has_warning and not $nowarning and not $silent) {
+        foreach my $w ($self->all_warnings) {
             $warn_h{$w} = 1 ;
             next if $old_warn->{$w} ;
             my $str = defined $value ? "'$value'" : '<undef>';
@@ -1114,11 +1225,17 @@ sub check {
     }
     $self->{old_warning_hash} = \%warn_h ;
 
-    my $e = $self->{error_list} ;
-    return wantarray ? @$e : not scalar @$e ;
+    return wantarray ? $self->all_errors : $self->is_ok ;
 }
 
 
+# callback with ($value, $error_ref, $warning_ref) ?
+
+# create a callback that wraps:
+# actual store in internal structure
+# user callback
+# notify_change
+# call to warp master
 
 sub store {
     my $self = shift ;
@@ -1128,58 +1245,117 @@ sub store {
     my $check = $self->_check_check($args{check}) ;
     my $silent = $args{silent} || 0 ;
 
-    my $old_value = $self->_fetch_no_check ;
+    my $str = $args{value} // '<undef>' ;
+    $logger->debug("called with '$str' on ", $self->composite_name) if $logger->is_debug;
 
-    my $value = $self->pre_store(value => $args{value}, check => $check ) ;
+    # store with check skip makes sense when force loading data: bad value
+    # is discarded, partially consistent values are stored so the user may
+    # salvage them before next save check discard them
 
-    $self->needs_check(1) ;
-    my $ok = $self->store_check($value) ;
+    # $self->{data} represents what written in the file
+    my $old_value = $self->{data} ;
+
+    my $value = $self->transform_value(value => $args{value}, check => $check ) ;
 
-    if ($logger->is_debug) {
-	my $i = $self->instance ;
-	my $msg = "value store $value, ok '$ok', check is $check";
-	map { $msg .= " $_" if $i->$_() } qw/layered preset/ ;
-	$logger->debug($msg) ; 
-    }
-    
     my $init_load = $self->instance->initial_load ;
     no warnings qw/uninitialized/;
     my $notify_change 
 	= $args{value} ne $value                ? 1 # data was transformed by model 
 	: $value ne $old_value and ! $init_load ? 1 
 	:                                         0 ;
+
+    if (defined $old_value and $value eq $old_value) {
+        $logger->info("skip storage of ",$self->composite_name," unchanged value: $value")
+            if $logger->is_debug ;
+        return 1;
+    }
+
     use warnings qw/uninitialized/;
     
-    # we let store the value even if wrong when check is disabled
-    if ($ok or $check eq 'no') {
-        if ($self->instance->layered) {
-	    $self->{layered} = $value ;
-	} 
-	elsif ($self->instance->preset) {
-	    $self->notify_change(check_done => 1,old => $self->{data}, new => $value)
-                if $notify_change;
-	    $self->{preset} = $value ;
-	} 
-	else {
-	    no warnings 'uninitialized';
-	    $self->notify_change(
-                check_done => 1,
-                old => $self->{data} // $self->_fetch_std, 
-                new => $value // $self->_fetch_std
-            ) if $notify_change;
-	    $self->{data} = $value ; # may be undef
-	}
-	
+
+    $self->needs_check(1) ; # always when storing a value
+    my $user_cb = $args{callback} || sub {} ;
+
+    # record a "pending_store" status so that fetch blocks until
+    # pending_store is cleared (necessary if warp stuff is read before the store is finished)
+    $async_logger->debug("incrementing pending store for ",$self->composite_name)
+        if $logger->is_debug ;
+    $self->inc_pending_store ;
+    my $my_cb = sub {
+        # must dec the counter before calling the user's cb. (which may contain a fetch call)
+        $async_logger->debug("decrementing pending store for ",$self->composite_name)
+            if $logger->is_debug ;
+        $self->dec_pending_store;
+        $self->store_cb(@_ , callback => $user_cb) ;
+    };
+
+    $self->check_stored_value(
+        value => $value,
+        check => $check,
+        silent => $silent,
+        notify_change => $notify_change, 
+        callback => $my_cb
+    ) ;
+}
+
+#
+# New subroutine "_store_value" extracted - Wed Jan 16 18:46:22 2013.
+#
+sub _store_value {
+    my $self          = shift;
+    my $value         = shift;
+    my $notify_change = shift // 1;
+
+    if ( $self->instance->layered ) {
+        $self->{layered} = $value;
     }
-    elsif ($check eq 'skip') {
-        my $msg = $self->error_msg;
-        warn "Warning: skipping value $value because of the following errors:\n$msg\n\n"
-          if not $silent and $msg;
+    elsif ( $self->instance->preset ) {
+        $self->notify_change( check_done => 1, old => $self->{data}, new => $value )
+          if $notify_change;
+        $self->{preset} = $value;
     }
     else {
-        Config::Model::Exception::WrongValue 
-	    -> throw ( error => join("\n\t",@{$self->{error_list}}),
-		       object => $self) ;
+        no warnings 'uninitialized';
+        my $old = $self->{data} // $self->_fetch_std ;
+        my $new = $value // $self->_fetch_std ;
+        $self->notify_change(
+            check_done => 1,
+            old        => $old,
+            new        => $new
+        ) if $notify_change and ($old ne $new);
+        $self->{data} = $value;    # may be undef
+    }
+    return $value ;
+}
+
+sub store_cb {
+    my $self = shift;
+    my %args = @_ ;
+
+    my ($value, $check, $silent, $notify_change, $ok, $callback) 
+        = @args{qw/value check silent notify_change ok callback/} ;
+
+    if ($logger->is_debug) {
+	my $i = $self->instance ;
+	my $msg = "value store $value, ok '$ok', check is $check";
+	map { $msg .= " $_" if $i->$_() } qw/layered preset/ ;
+	$logger->debug($msg) ;
+    }
+
+    my $old_value = $self->_fetch_no_check ;
+
+    # FIXME: storing wrong value does not make sense
+    # we let store the value even if wrong when check is disabled
+    if ($ok or $check eq 'no') {
+        $self->instance->cancel_error($self->location) ;
+        $self-> _store_value ( $value,$notify_change) ;
+    }
+    else {
+        $self->instance->add_error($self->location) ;
+        my $msg = $self->error_msg;
+        no warnings 'uninitialized';
+        warn "Warning: skipping value $value because of the following errors:\n$msg\n\n"
+          if not $silent and $msg;
     }
 
     if (    $ok 
@@ -1191,12 +1367,35 @@ sub store {
 	$self->trigger_warp($value) ;
     }
 
-    return $value;
+    $callback->(%args) ;
+    $logger->debug("store_cb done on ",$self->composite_name) if $logger->is_debug ;
 }
 
-# internal. return ( 1|0, value)
+#
+# New subroutine "transform_boolean" extracted - Thu Sep 19 18:58:21 2013.
+#
+sub transform_boolean {
+    my $self  = shift;
+    my $v_ref = shift;
+
+    return unless defined $$v_ref;
+
+    if ( my $wa = $self->{write_as} ) {
+        my $i = 0;
+        map {
+            $$v_ref = $i if ($wa->[$i] eq $$v_ref);
+            $i++
+        } @$wa;
+    }
+
+    # convert yes no to 1 or 0
+    $$v_ref = 1 if ( $$v_ref =~ /^y/i or $$v_ref =~ /true/i );
+    $$v_ref = 0 if ( $$v_ref =~ /^n/i or $$v_ref =~ /false/i );
+}
+
+# internal. return ( undef, value)
 # May return an undef value if actual store should be skipped
-sub pre_store {
+sub transform_value {
     my $self = shift ;
     my %args = @_ > 1 ? @_ : (value => $_[0]) ;
     my $value = $args{value} ;
@@ -1215,24 +1414,14 @@ sub pre_store {
 	Config::Model::Exception::Model
 	    -> throw (object => $self, message => $msg) 
 	      if $check eq 'yes';
-        return 1 ; 
+        return ; 
     }
 
     if (defined $self->{refer_to} or defined $self->{computed_refer_to}) {
 	$self->{ref_object}->get_choice_from_refered_to ;
     }
 
-    # check if the object was initialized
-    if (not defined $self->{value_type}) {
-        $self->_value_type_error if $check eq 'yes';
-	return 0 ;
-    }
-
-    if ($self->{value_type} eq 'boolean' and defined $value) {
-        # convert yes no to 1 or 0 
-        $value = 1 if ($value =~ /^y/i or $value =~ /true/i) ;
-        $value = 0 if ($value =~ /^n/i or $value =~ /false/i );
-    }
+    $self->transform_boolean (\$value) if $self->value_type eq 'boolean';
 
     $value = $self->{convert_sub}($value) 
       if (defined $self->{convert_sub} and defined $value) ;
@@ -1253,12 +1442,68 @@ sub pre_store {
         }
     }
     
+    # using default or computed value is normally done on fetch. Except that an undefined
+    # value cannot be stored in a mandatory value. Storing undef is used when resetting a 
+    # value to default. If a value is mandatory, we must store the default (or best equivalent)
+    # instead
+    if ((not defined $value or not length($value)) and $self->mandatory) {
+        delete $self->{data} ; # avoiding recycling the old stored value
+        $value = $self->_fetch_no_check ;
+    }
+
     return $value;
 }
 
-# dummy routine to enable special store check in inherited classes
-sub store_check {
-    goto &check ;
+# store check must be async
+sub check_stored_value {
+    my $self = shift;
+
+    $async_logger->debug(
+        "called for " . $self->location . " from " . join( ' ', caller ),
+        " with @_" )
+      if $async_logger->is_debug;
+
+    my %args = @_;
+
+    my $cb = delete $args{callback} || croak "check_stored_value: no callback" ;
+    my $my_cb = sub {
+        $self->check_stored_value_cb(@_, callback => $cb) ;
+    } ;
+
+
+    $self->check_value(%args, callback => $my_cb);
+}
+
+sub check_stored_value_cb {
+    my $self = shift;
+    my %args = @_ ;
+
+    my ($value, $check, $silent, $notify_change, $ok, $callback) 
+        = @args{qw/value check silent notify_change ok callback/} ;
+
+    $async_logger->debug("check_stored_value_cb called");
+
+    # some se case like idElementReference are too complex to propagate
+    # a change notification back to the value using them. So an error or
+    # warning must always be rechecked.
+    $self->needs_check(0) unless $self->has_error or $self->has_warning ;
+
+    # old_warn is used to avoid warning the user several times for the
+    # same reason. We take care to clean up this hash each time this routine
+    # is run
+    my $old_warn = $self->{old_warning_hash} || {} ;
+    my %warn_h ;
+    if ($self->has_warning and not $nowarning and not $silent) {
+        foreach my $w ($self->all_warnings) {
+            $warn_h{$w} = 1 ;
+            next if $old_warn->{$w} ;
+            my $str = defined $value ? "'$value'" : '<undef>';
+            warn "Warning in '" . $self->location . "' value $str: $w\n";
+        }
+    }
+    $self->{old_warning_hash} = \%warn_h ;
+
+    $callback->(%args) ;
 }
 
 # print a hopefully helpful error message when value_type is not
@@ -1286,7 +1531,10 @@ sub _value_type_error {
 
 sub load_data {
     my $self = shift ;
-    my $data  = shift ;
+
+    my %args = @_ > 1 ? @_ : ( data => shift) ;
+    my $data       = $args{data};
+    my $check = $self->_check_check($args{check}) ;
 
     if (ref $data) {
 	Config::Model::Exception::LoadData
@@ -1395,10 +1643,9 @@ sub _fetch {
     my $pref = $self->_fetch_std($mode, $check) ;
 
     my $data = $self->{data} ;
-    my $old_data = $data // $self->{_std_backup} ;
-    if (defined $pref  and not defined $old_data) {
-        $self->{_std_backup} = $pref ;
-        $self->notify_change(old => $old_data, new => $pref, note => "use standard value") ;
+    if (defined $pref  and not $self->{notified_change_for_default} and not defined $data) {
+        $self->{notified_change_for_default} = 1 ;
+        $self->notify_change(old => undef, new => $pref, note => "use standard value") ;
     }
 
     my $known_upstream = defined $self->{layered} ? $self->{layered}
@@ -1511,8 +1758,10 @@ sub fetch {
             mode => 'loose',
             autoadd => 0,
         ); 
-        # stire replaced value to trigger notify_change         
-        $value = $self->store($rep) if defined $rep ;
+        # store replaced value to trigger notify_change
+        if (defined $rep  and $rep ne $value) {
+             $value = $self->_store_value($rep) ;
+        };
     }
 
     # check and subsequent storage of fixes instruction must be done only
@@ -1538,7 +1787,7 @@ sub fetch {
     
     Config::Model::Exception::WrongValue->throw(
         object => $self,
-        error  => join( "\n\t", @{ $self->{error_list} } )
+        error  => $self->error_msg
     );
 
     return;
@@ -1648,19 +1897,21 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
+# ABSTRACT:  Strongly typed configuration value
+
 __END__
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -1782,13 +2033,12 @@ application. This value must be written in the configuration file.
 C<computed>: The value is computed from other configuration
 elements. This value must be written in the configuration file.
 
-
 =item *
 
 C<preset>: The value is not known by the model or by the
 application. But it can be found by an automatic program and stored
 while the configuration L<Config::Model::Instance|instance> is in 
-L<Config::Model::Instance/"preset_start ()"|preset mode>
+L<preset mode|Config::Model::Instance/"preset_start ()">
 
 =back
 
@@ -1839,7 +2089,7 @@ computed value declaration.
 
 This is a special parameter to cater for smooth configuration
 upgrade. This parameter can be used to copy the value of a deprecated
-parameter to its replacement. See L<"/upgrade"> for details.
+parameter to its replacement. See L</Upgrade> for details.
 
 =item convert => [uc | lc ]
 
@@ -1909,7 +2159,6 @@ The example below will warn if a directory is missing:
 
   warn_unless => { 'dir' => { code => '-d' , msg => 'missing dir', fix => "system(mkdir $_);" }}
 
-
 =item assert
 
 Like C<warn_if_match>. Except that returned value will trigger an error if false.
@@ -1952,7 +2201,7 @@ The hash key can also be a regular expression for wider range replacement.
 The regexp must match the whole value:
 
   replace => ( 'foo.*' => 'better_foo' }
-  
+
 In this case, a value will be replaced by C<better_foo> if the 
 C</^foo.*$/> regexp matches. 
 
@@ -2028,7 +2277,7 @@ another location if the configuration tree. See L</Value Reference>.
 The Warp functionality enable a C<Value> object to change its
 properties (i.e. default value or its type) dynamically according to
 the value of another C<Value> object locate elsewhere in the
-configuration tree. (See L<Config::Model::WarpedThing> for an
+configuration tree. (See L<Config::Model::Warper> for an
 explanation on warp mechanism).
 
 For instance if you declare 2 C<Value> element this way:
@@ -2237,11 +2486,14 @@ Without C<value> argument, this method will check the value currently stored.
 
 =head2 store( value )
 
-Can be called as C<< value => ...,  check => yes|no|skip ) >>
+Can be called as C<< value => ...,  check => yes|no|skip, callback => sub {...} ) >>
 
 Store value in leaf element. C<check> parameter can be used to 
 skip validation check.
 
+Optional C<callback> is called when store check is done with these named parameters:
+C<value check notify_change ok>.
+
 =head2 load_data( scalar_value )
 
 Load scalar data. Data is simply forwarded to L<store>.
@@ -2412,7 +2664,7 @@ Set a value from a directory like path.
     type       => 'leaf',
     value_type => 'boolean',
   },
- 
+
 =head2 Enum with help associated with each value 
 
 Note that the help specification is optional.
@@ -2449,10 +2701,10 @@ regular expression.
     value_type => 'string',
     match      => '^foo\d{2}$',
   },
-  
+
 =head2 Enforce value to match a L<Parse::RecDescent> grammar
 
-  prd_match => {
+  match_with_parse_recdescent => {
     type       => 'leaf',
     value_type => 'string',
     grammar    => q{ 
@@ -2472,7 +2724,7 @@ translate all capital letters to lower case.
     value_type    => 'string',
     warn_if_match => { '/A-Z/' => { fix => '$_ = lc;' } },
   },
- 
+
 A specific warning can be specified:
 
   warn_if_capital => {
@@ -2487,13 +2739,13 @@ A specific warning can be specified:
   },
 
 =head2 Issue a warning if a value does NOT match a regexp 
-  
+
   warn_unless => {
     type              => 'leaf',
     value_type        => 'string',
     warn_unless_match => { foo => { msg => '', fix => '$_ = "foo".$_;' } },
   },
-  
+
 =head2 Always issue a warning 
 
   always_warn => {
@@ -2556,7 +2808,6 @@ parameters (host and path):
 				   },
 		 },
 
-
 =head1 EXCEPTION HANDLING
 
 When an error is encountered, this module may throw the following
@@ -2576,7 +2827,19 @@ Dominique Dumont, (ddumont at cpan dot org)
 =head1 SEE ALSO
 
 L<Config::Model>, L<Config::Model::Node>,
-L<Config::Model::AnyId>, L<Config::Model::WarpedThing>, L<Exception::Class>
+L<Config::Model::AnyId>, L<Config::Model::Warper>, L<Exception::Class>
 L<Config::Model::ValueComputer>,
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
