@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::Value::LayeredInclude;
 {
-  $Config::Model::Value::LayeredInclude::VERSION = '2.029';
+  $Config::Model::Value::LayeredInclude::VERSION = '2.047';
 }
 
 
@@ -20,33 +20,25 @@ use Log::Log4perl qw(get_logger :levels);
 
 use base qw/Config::Model::Value/ ;
 
-# override store to trigger a refresh of layered value when value is actually
-# changed. 
+
+my $logger = get_logger("Tree::Element::Value::LayeredInclude") ;
 
 # should we clear all layered value when include value is changed ? 
 # If yes, beware of recursive includes. Clear should only be done once.
 
-# beware: 2 kind of includes: shadow include (set default values like 
-# multistrap or ssh, i.e. read-only includes) and real includes (apache,
-# i.e. may write back in included files)
-
-# this class deals only with the first type
-
-my $logger = get_logger("Tree::Element::Value::LayeredInclude") ;
-
-sub store {
+sub store_cb {
     my $self = shift ;
-    my %args = @_ == 1 ? (value => $_[0]) 
-             : @_ == 3 ? ( 'value' , @_ ) 
-             : @_ ;
+    my %args = @_ ;
 
-    my $old_data = $self->{data} ;
-    
-    my $new_data = $self->SUPER::store(%args) ; 
+    my ($value, $check, $silent, $notify_change, $ok, $callback)
+        = @args{qw/value check silent notify_change ok callback/} ;
+
+    my $old_value = $self->_fetch_no_check;
     
+    $self->SUPER::store_cb(%args) ;
     {
         no warnings 'uninitialized' ;
-        return $new_data if $new_data eq $old_data;   
+        return $value if $value eq $old_value;
     }
     
     my $i = $self->instance ;
@@ -60,13 +52,13 @@ sub store {
     
     {
         no warnings 'uninitialized';
-        $logger->debug("Loading layered config from $new_data (old_data is $old_data)") ;
+        $logger->debug("Loading layered config from $value (old_data is $old_value)") ;
     }
     
     # load included file in layered mode
     $self->root->read_config_data(
-        check => 'no', 
-        config_file => $new_data ,
+        # check => 'no',
+        config_file => $value ,
         auto_create => 0, # included file must exist
     );
 
@@ -75,9 +67,9 @@ sub store {
     }
     
     # test if already in layered mode -> if no, clear layered, 
-    $logger->debug("Done loading layered config from $new_data") ;
+    $logger->debug("Done loading layered config from $value") ;
     
-    return $new_data ;
+    return $value ;
 }
 
 sub _check_value {
@@ -106,56 +98,80 @@ sub _check_value {
 }
 1;
 
+# ABSTRACT: Include a sub layer configuration
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Value::LayeredInclude - Include a sub layer configuration
 
 =head1 VERSION
 
-version 2.029
+version 2.047
 
 =head1 SYNOPSIS
 
-  my $object = Config::Model::Value::Include->new(
-      foo  => 'bar',
-      flag => 1,
-  );
-  
-  $object->dummy;
+    # in a model declaration:
+    'element' => [
+      'include' => {
+        'class' => 'Config::Model::Value::LayeredInclude',
+
+        # usual Config::Model::Value parameters
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'convert' => 'lc',
+        'summary' => 'Include file for cascaded configuration',
+        'description' => 'To support multiple variants of ...'
+      },
+    ]
 
 =head1 DESCRIPTION
 
-The author was too lazy to write a description.
+This class inherits from L<Config::Model::Value>. It overrides
+L<store_cb> to trigger a refresh of layered value when value is actually
+changed. I.e. changing this value will reload the refered configuration
+file and use its values as default value. This class was designed to
+cope with L<multistrap|http://wiki.debian.org/Multistrap> configuration.
 
-=head1 METHODS
+=head2 CAUTION
 
-=head2 new
+A configuration file can support 2 kinds of include:
 
-  my $object = Config::Model::Value::Include->new(
-      foo => 'bar',
-  );
+=over
 
-The C<new> constructor lets you create a new B<Config::Model::Value::Include> object.
+=item *
 
-So no big surprises there...
+Layered include which sets default values like multistrap or ssh. These includes are
+read-only.
 
-Returns a new B<Config::Model::Value::Include> or dies on error.
+=item *
 
-=head2 dummy
+Real includes like C<apache>. In this cases modified configuration items can be written to
+included files.
 
-This method does something... apparently.
+=back
 
-=head1 SUPPORT
-
-No support is available
+This class works only with the first type
 
 =head1 AUTHOR
 
-Copyright 2011 Anonymous.
+Copyright 2011,2013 Dominique Dumont <ddumont at cpan.org>
+
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
 
 =cut
