@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,10 +9,10 @@
 #
 package Config::Model::Warper ;
 {
-  $Config::Model::Warper::VERSION = '2.021';
+  $Config::Model::Warper::VERSION = '2.047';
 }
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Log::Log4perl qw(get_logger :levels);
@@ -228,7 +228,7 @@ sub refresh_values_from_master {
             mode => 'loose',
         );
 
-        if ( defined $warper ) {
+        if ( defined $warper and $warper->get_type eq 'leaf') {
             # read the warp master values, so I can warp myself just
             # after.
             my $warper_value = $warper->fetch('allow_undef') ;
@@ -237,6 +237,13 @@ sub refresh_values_from_master {
                 . "'" );
             $self->_set_value( $warper_name => $warper_value );
         }
+		elsif (defined $warper) {
+			Config::Model::Exception::Model -> throw (
+				error => "warp error: warp 'follow' parameter "
+						  ."does not point to a leaf element",
+				object => $self->warped_object
+		       ) ;
+		}
         else {
             # consider that the warp master value is undef
             $self->_set_value($warper_name,'');
@@ -581,15 +588,23 @@ sub warp_error {
 
 __PACKAGE__->meta->make_immutable;
 
+# ABSTRACT: Warp tree properties
+
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Config::Model::Warper - Warp tree properties
 
 =head1 VERSION
 
-version 2.021
+version 2.047
 
 =head1 SYNOPSIS
 
@@ -659,7 +674,6 @@ be applied. In this case, rules is a list ref:
              '$m eq "B" or $m eq"C "'  => { <effect for macro1 == B|C > }
            ]
 
-
 In case of several warp masters, C<follow> must use named parameters, and
 rules must use boolean expression:
 
@@ -697,8 +711,6 @@ eval, so you can use most Perl syntax and regular expressions.
 Function (like C<&foo>) will be called like C<< $self->foo >> before evaluation\
 of the boolean expression.
 
-=cut
-
 =head1 Methods
 
 =head2 warp_error()
@@ -722,9 +734,6 @@ warp master is an enumerated type)
 
 =back
 
-=cut
-
-
 =head1 How does this work ?
 
 =over
@@ -784,4 +793,16 @@ L<Config::Model::ListId>,
 L<Config::Model::WarpedNode>,
 L<Config::Model::Value>
 
+=head1 AUTHOR
+
+Dominique Dumont
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2013 by Dominique Dumont.
+
+This is free software, licensed under:
+
+  The GNU Lesser General Public License, Version 2.1, February 1999
+
 =cut
